<?php 
/* 
 ----------------------------------------------------------------------
 GLPI - Gestionnaire Libre de Parc Informatique
 Copyright (C) 2003-2010 by the INDEPNET Development Team.
 
 http://indepnet.net/   http://glpi-project.org
 ----------------------------------------------------------------------

 LICENSE

 This file is part of GLPI.

 GLPI is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2 of the License, or
 (at your option) any later version.

 GLPI is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with GLPI; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 ------------------------------------------------------------------------
 */
//dk_DK

$LANG=array();


$LANG['backup'][0]="SQL Dump"; 
$LANG['backup'][1]="XML Dump"; 
$LANG['backup'][11]="Størrelse"; 
$LANG['backup'][13]="Se/Download"; 
$LANG['backup'][16]="Erstat den aktuelle database med backupfilen:"; 
$LANG['backup'][17]="Slet denne fil"; 
$LANG['backup'][18]="Sikkerhedskopier databasen"; 
$LANG['backup'][19]="Nu"; 
$LANG['backup'][21]="Filen eksisterer allerede"; 
$LANG['backup'][22]="Kan ikke finde byte"; 
$LANG['backup'][23]="MySQL fejl startende ved"; 
$LANG['backup'][24]="Automatisk viderestilling, ellers klik"; 

$LANG['bookmark'][1]="bogmærke"; 
$LANG['bookmark'][2]="Partial load of the bookmark."; 
$LANG['bookmark'][3]="Du har endnu ikke angivet bogmærker"; 
$LANG['bookmark'][4]="Nyt bogmærke"; 
$LANG['bookmark'][5]="Offentligt bogmærke"; 
$LANG['bookmark'][6]="Tilføj som standard"; 

$LANG['buttons'][0]="Søg"; 
$LANG['buttons'][2]="Post"; 
$LANG['buttons'][3]="Tilknyt"; 
$LANG['buttons'][4]="Install"; 
$LANG['buttons'][5]="Uninstall"; 
$LANG['buttons'][6]="Slet"; 
$LANG['buttons'][7]="Opdatér"; 
$LANG['buttons'][8]="Tilføj"; 
$LANG['buttons'][9]="Forbind"; 
$LANG['buttons'][10]="Frakobl"; 
$LANG['buttons'][11]="Næste"; 
$LANG['buttons'][12]="Forrige"; 
$LANG['buttons'][13]="Tilbage"; 
$LANG['buttons'][14]="Opdatér"; 
$LANG['buttons'][15]="Planlæg"; 
$LANG['buttons'][16]="Blank"; 
$LANG['buttons'][17]="Inverter det valgte"; 
$LANG['buttons'][18]="Markér alle"; 
$LANG['buttons'][19]="Fravælg Alle"; 
$LANG['buttons'][20]="Flyt"; 
$LANG['buttons'][21]="Gendan"; 
$LANG['buttons'][22]="Slet"; 
$LANG['buttons'][23]="Vis"; 
$LANG['buttons'][24]="Op"; 
$LANG['buttons'][25]="Ned"; 
$LANG['buttons'][27]="Aktuel side i PDF"; 
$LANG['buttons'][28]="Aktuel side i SLK"; 
$LANG['buttons'][29]="Alle sider i PDF"; 
$LANG['buttons'][30]="Alle sider i SLK"; 
$LANG['buttons'][31]="Eksport"; 
$LANG['buttons'][32]="Slut"; 
$LANG['buttons'][33]="Start"; 
$LANG['buttons'][34]="Annuller"; 
$LANG['buttons'][37]="Import"; 
$LANG['buttons'][38]="Lås op"; 
$LANG['buttons'][39]="Erstat"; 
$LANG['buttons'][40]="Vis alt"; 
$LANG['buttons'][41]="Aktiver"; 
$LANG['buttons'][42]="Deaktiver"; 
$LANG['buttons'][43]="Gennemse"; 
$LANG['buttons'][44]="Aktuel side i CSV"; 
$LANG['buttons'][45]="Alle sider i CSV"; 
$LANG['buttons'][46]="Før"; 
$LANG['buttons'][47]="Efter"; 
$LANG['buttons'][48]="Overfør"; 
$LANG['buttons'][49]="Behold"; 
$LANG['buttons'][50]="Test"; 
$LANG['buttons'][51]="Gem"; 
$LANG['buttons'][52]="Indlæs"; 
$LANG['buttons'][53]="Ryd"; 
$LANG['buttons'][55]="Først"; 
$LANG['buttons'][56]="Sidst"; 
$LANG['buttons'][57]="Udfør"; 
$LANG['buttons'][58]="Opdater"; 
$LANG['buttons'][59]="Fjern tilknytning"; 

$LANG['calendar'][0]="YYYY-MM-DD"; 
$LANG['calendar'][1]="DD-MM-YYYY"; 
$LANG['calendar'][2]="MM-DD-YYYY"; 

$LANG['calendarD'][0]="S"; 
$LANG['calendarD'][1]="M"; 
$LANG['calendarD'][2]="T"; 
$LANG['calendarD'][3]="W"; 
$LANG['calendarD'][4]="T"; 
$LANG['calendarD'][5]="F"; 
$LANG['calendarD'][6]="S"; 

$LANG['calendarDay'][0]="Søndag"; 
$LANG['calendarDay'][1]="Mandag"; 
$LANG['calendarDay'][2]="Torsdag"; 
$LANG['calendarDay'][3]="Onsdag"; 
$LANG['calendarDay'][4]="Torsdag"; 
$LANG['calendarDay'][5]="Fredag"; 
$LANG['calendarDay'][6]="Lørdag"; 

$LANG['calendarM'][0]="Januar"; 
$LANG['calendarM'][1]="Februar"; 
$LANG['calendarM'][2]="Marts"; 
$LANG['calendarM'][3]="April"; 
$LANG['calendarM'][4]="Maj"; 
$LANG['calendarM'][5]="Juni"; 
$LANG['calendarM'][6]="Juli"; 
$LANG['calendarM'][7]="August"; 
$LANG['calendarM'][8]="September"; 
$LANG['calendarM'][9]="Oktober"; 
$LANG['calendarM'][10]="November"; 
$LANG['calendarM'][11]="December"; 

$LANG['cartridges'][0]="Patron"; 
$LANG['cartridges'][7]="Ingen patron fundet"; 
$LANG['cartridges'][9]="Ingen patron"; 
$LANG['cartridges'][10]="Toner"; 
$LANG['cartridges'][11]="Ink-Jet"; 
$LANG['cartridges'][12]="Patrontype"; 
$LANG['cartridges'][13]="Ny"; 
$LANG['cartridges'][14]="Tom"; 
$LANG['cartridges'][15]="Brugt"; 
$LANG['cartridges'][16]="Patron(er)"; 
$LANG['cartridges'][20]="Ny"; 
$LANG['cartridges'][21]="Tom"; 
$LANG['cartridges'][22]="Brugt"; 
$LANG['cartridges'][24]="Tilføj dato"; 
$LANG['cartridges'][27]="Tændt"; 
$LANG['cartridges'][29]="Udløbs dato"; 
$LANG['cartridges'][32]="Kompatible printer modeller"; 
$LANG['cartridges'][33]="Tomme patroner"; 
$LANG['cartridges'][34]="Ingen ledig patron"; 
$LANG['cartridges'][35]="Brugte patroner"; 
$LANG['cartridges'][37]="Farvebånd"; 
$LANG['cartridges'][39]="Printer tæller"; 
$LANG['cartridges'][40]="Gennemsnitlig tid på lager"; 
$LANG['cartridges'][41]="Gennemsnitlig tid i brug"; 
$LANG['cartridges'][42]="Gennemsnitlig antal af printede sider"; 

$LANG['central'][2]="Sidste"; 
$LANG['central'][4]="Ingen begivenheder"; 
$LANG['central'][5]="Hjem"; 
$LANG['central'][6]="Log af"; 
$LANG['central'][7]="Hjælp"; 
$LANG['central'][8]="Tilføjelser"; 
$LANG['central'][9]="Dine påbegyndte sager"; 
$LANG['central'][10]="Nye sager"; 
$LANG['central'][12]="Personlig visning"; 
$LANG['central'][13]="Global visning"; 
$LANG['central'][14]="Gruppevisning"; 
$LANG['central'][18]="Dine sager til lukning"; 
$LANG['central'][19]="Dine sager til godkendelse"; 

$LANG['choice'][0]="Nej"; 
$LANG['choice'][1]="Ja"; 

$LANG['common'][0]="Uden navn"; 
$LANG['common'][1]="Enhed"; 
$LANG['common'][2]="ID"; 
$LANG['common'][3]="Vis affaldet"; 
$LANG['common'][4]="Web"; 
$LANG['common'][5]="Producent"; 
$LANG['common'][6]="Skabelon navn"; 
$LANG['common'][7]="Vælg en skabelon"; 
$LANG['common'][8]="Administrer skabeloner..."; 
$LANG['common'][9]="Tilføj en skabelon..."; 
$LANG['common'][10]="Ansvarlig tekniker"; 
$LANG['common'][11]="Begrænset visning"; 
$LANG['common'][12]="Opsæt"; 
$LANG['common'][13]="Skabelon"; 
$LANG['common'][14]="Skabeloner"; 
$LANG['common'][15]="Lokation"; 
$LANG['common'][16]="Navn"; 
$LANG['common'][17]="Type"; 
$LANG['common'][18]="Alternativt brugernavn"; 
$LANG['common'][19]="Serienummer"; 
$LANG['common'][20]="Lager nummer"; 
$LANG['common'][21]="Alternativt brugernavns-nummer"; 
$LANG['common'][22]="Model"; 
$LANG['common'][23]="Handlingen lykkedes"; 
$LANG['common'][24]="Ingen valgte emner eller dårlig defineret opgave"; 
$LANG['common'][25]="Kommentarer"; 
$LANG['common'][26]="Sidst opdateret"; 
$LANG['common'][27]="Dato"; 
$LANG['common'][28]="Slettet"; 
$LANG['common'][29]="Plugins"; 
$LANG['common'][30]="Ny enhed"; 
$LANG['common'][31]="Tom skabelon"; 
$LANG['common'][32]="Egenskaber"; 
$LANG['common'][33]="Total"; 
$LANG['common'][34]="Bruger"; 
$LANG['common'][35]="Gruppe"; 
$LANG['common'][36]="Kategori (klasse)"; 
$LANG['common'][37]="Forfatter"; 
$LANG['common'][38]="Brug enheds håndtering"; 
$LANG['common'][39]="Kopiér emnet lige så mange gange som der er forbindelser"; 
$LANG['common'][40]="Ønsker du virkelig at bruge enheds håndtering for dette emne ?"; 
$LANG['common'][41]="E-mail alarmer"; 
$LANG['common'][42]="Mobiltelefon"; 
$LANG['common'][43]="Fornavn"; 
$LANG['common'][44]="Standard værdi(er)"; 
$LANG['common'][45]="MB Maks."; 
$LANG['common'][46]="Vcard"; 
$LANG['common'][47]="Forløb"; 
$LANG['common'][48]="Efternavn"; 
$LANG['common'][49]="Ingen"; 
$LANG['common'][50]="Bekræft den endelige sletning ?"; 
$LANG['common'][51]="Fulde navn"; 
$LANG['common'][52]="Server"; 
$LANG['common'][53]="Liste"; 
$LANG['common'][54]="Emne ikke fundet"; 
$LANG['common'][55]="Er du sikker på at du ønsker at slette dette emne?"; 
$LANG['common'][56]="Standard grænseflade"; 
$LANG['common'][57]="Tittel"; 
$LANG['common'][58]="Maksimum værdi"; 
$LANG['common'][59]="Global"; 
$LANG['common'][60]="Aktiv"; 
$LANG['common'][61]="Ukendt fejl"; 
$LANG['common'][62]="Andet"; 
$LANG['common'][63]="Fejl"; 
$LANG['common'][64]="Manager"; 
$LANG['common'][65]="Grænseflade"; 
$LANG['common'][66]="Alle"; 
$LANG['common'][67]="Andre"; 
$LANG['common'][68]="Landskab"; 
$LANG['common'][69]="Portræt"; 
$LANG['common'][70]="Enhed tilføjet korrekt"; 
$LANG['common'][71]="Emne korrekt opdateret"; 
$LANG['common'][72]="Enhed korrekt slettet"; 
$LANG['common'][73]="Emnet er slettet korrekt"; 
$LANG['common'][74]="Emne korrekt gendannet"; 
$LANG['common'][75]="No right to make this item recursive in this entity"; 
$LANG['common'][76]="Offentlig"; 
$LANG['common'][77]="Privat"; 
$LANG['common'][78]="Gør offentlig"; 
$LANG['common'][79]="Gør personlig"; 
$LANG['common'][80]="Indlæser"; 
$LANG['common'][81]="Vis ikke slettede enheder"; 
$LANG['common'][82]="MB"; 
$LANG['common'][83]="Du har ikke rettighed til at udføre denne handling."; 
$LANG['common'][84]="Flag change forbidden. Linked items found."; 
$LANG['common'][85]="Tilpas synlighed for under-entiteter"; 
$LANG['common'][86]="Du har ikke tilladelse til at ændre synlighedsflaget for underentiteter."; 
$LANG['common'][87]="Nyt kort"; 
$LANG['common'][88]="Personlig"; 
$LANG['common'][89]="Ikke installeret"; 
$LANG['common'][90]="Objekt"; 
$LANG['common'][91]="Kan ikke ændre denne attribut. Den er arvet fra dens forældre."; 
$LANG['common'][92]="Alternativt brugernavn"; 
$LANG['common'][93]="New child heading"; 

$LANG['computers'][0]="Volume"; 
$LANG['computers'][1]="Ledig procentdel"; 
$LANG['computers'][2]="Ledig størrelse"; 
$LANG['computers'][3]="Global størrelse"; 
$LANG['computers'][4]="Filsystem"; 
$LANG['computers'][5]="Monteringspunkt"; 
$LANG['computers'][6]="Partition"; 
$LANG['computers'][7]="Tilføj en volumen"; 
$LANG['computers'][8]="Volumner"; 
$LANG['computers'][9]="Operativsystem"; 
$LANG['computers'][10]="Operativsystemets serienummer"; 
$LANG['computers'][11]="Operativsystemets produkt-id"; 
$LANG['computers'][14]="Indsat"; 
$LANG['computers'][23]="Hukommelsestype"; 
$LANG['computers'][24]="Hukommelse (MB)"; 
$LANG['computers'][25]="Harddisk størrelse"; 
$LANG['computers'][36]="Harddisk type"; 
$LANG['computers'][37]="Ingen tilsluttede skærme"; 
$LANG['computers'][38]="Ingen tilsluttet printer"; 
$LANG['computers'][39]="Printere"; 
$LANG['computers'][40]="Skærm(e)"; 
$LANG['computers'][46]="Enheder"; 
$LANG['computers'][47]="Ingen tilsluttede enheder"; 
$LANG['computers'][48]="Location updated. The items connected have been moved in the same location."; 
$LANG['computers'][49]="Alternativt brugernavn opdateret. De forbunde enheder er blevet opdateret ved brug af dette alternative brugernavn."; 
$LANG['computers'][50]="User or group updated. The items connected have been moved in the same values."; 
$LANG['computers'][51]="opdateringskilde"; 
$LANG['computers'][52]="Operativsystemets version"; 
$LANG['computers'][53]="Service Pack"; 
$LANG['computers'][54]="Ingen telefon tilsluttet"; 
$LANG['computers'][55]="Telefon"; 
$LANG['computers'][56]="Status opdateret. De tilknyttede emner er opdateret med denne status."; 

$LANG['connect'][0]="Direkte forbindelse"; 
$LANG['connect'][1]="Ikke forbundet"; 
$LANG['connect'][15]="Automatisk opdatering af følgende emner"; 
$LANG['connect'][16]="Advarsel!! De følgende to hardware-emner passer ikke sammen"; 

$LANG['consumables'][0]="Forbrugsvarer"; 
$LANG['consumables'][1]="På lager"; 
$LANG['consumables'][2]="Reference"; 
$LANG['consumables'][7]="Ingen forbrugsvare fundet"; 
$LANG['consumables'][9]="Ingen forbrugsvare"; 
$LANG['consumables'][12]="Forbrugsvare-type"; 
$LANG['consumables'][13]="Ny"; 
$LANG['consumables'][15]="Brugt"; 
$LANG['consumables'][16]="Forbrugsvare"; 
$LANG['consumables'][20]="Ny"; 
$LANG['consumables'][22]="Brugt"; 
$LANG['consumables'][23]="Tilstand"; 
$LANG['consumables'][26]="Udløbsdato"; 
$LANG['consumables'][32]="Giv"; 
$LANG['consumables'][35]="Brugte forbrugsvarer"; 
$LANG['consumables'][36]="Lager beliggenhed"; 
$LANG['consumables'][37]="Tilbage til lager"; 
$LANG['consumables'][38]="Alarm grænse"; 

$LANG['contract'][0]="Kontrakt udløbet siden den"; 
$LANG['contract'][1]="Contract with notice since the"; 

$LANG['crontask'][0]="Automatiske hændelser"; 
$LANG['crontask'][1]="Synkronisér udstyr fra OCSNG"; 
$LANG['crontask'][2]="Send alarm vedr. patroner"; 
$LANG['crontask'][3]="Send alarm vedr. forbrugsvarer"; 
$LANG['crontask'][4]="Send alarm ved udløbede licenser"; 
$LANG['crontask'][5]="Send alarm vedr. kontrakter"; 
$LANG['crontask'][6]="Send alarm vedr. finansiel information"; 
$LANG['crontask'][7]="Ryd gamle logfiler"; 
$LANG['crontask'][8]="Database optimering"; 
$LANG['crontask'][9]="Indhent e-mail (Mail modtagere)"; 
$LANG['crontask'][10]="Kontrollér MySQL replika"; 
$LANG['crontask'][11]="Søg efter nye opdateringer"; 
$LANG['crontask'][12]="Ryd udløbede sessioner"; 
$LANG['crontask'][13]="Ryd genereret grafik"; 
$LANG['crontask'][14]="Automatisk sagslukning"; 
$LANG['crontask'][15]="Ikke-løste sager"; 
$LANG['crontask'][31]="Deaktiveret"; 
$LANG['crontask'][32]="Planlagt"; 
$LANG['crontask'][33]="Kører"; 
$LANG['crontask'][34]="GLPI"; 
$LANG['crontask'][35]="CLI"; 
$LANG['crontask'][36]="Kørsels-tilstand"; 
$LANG['crontask'][37]="Kørsels-frekvens"; 
$LANG['crontask'][38]="Kørsels-periode"; 
$LANG['crontask'][39]="Antal e-mail der skal indhentes"; 
$LANG['crontask'][40]="Sidste kørsel"; 
$LANG['crontask'][41]="Næste kørsel"; 
$LANG['crontask'][42]="Så hurtigt som muligt"; 
$LANG['crontask'][43]="Ingen ventende handlinger"; 
$LANG['crontask'][44]="Handling færdig, delvist behandlet"; 
$LANG['crontask'][45]="Handling færdig, helt behandlet"; 
$LANG['crontask'][46]="Handling færdig, intet at behandle"; 
$LANG['crontask'][47]="Sidste kørsel-liste"; 
$LANG['crontask'][48]="Start"; 
$LANG['crontask'][50]="Kørsels-antal"; 
$LANG['crontask'][51]="Minimum tid"; 
$LANG['crontask'][52]="Maksimal tid"; 
$LANG['crontask'][53]="Gennemsnitstid"; 
$LANG['crontask'][55]="Minimum antal"; 
$LANG['crontask'][56]="Maksimalt antal"; 
$LANG['crontask'][57]="Gennemsnits antal"; 
$LANG['crontask'][58]="Total antal"; 
$LANG['crontask'][59]="Gennemsnits-hastighed"; 
$LANG['crontask'][60]="Systemlås"; 
$LANG['crontask'][61]="Deaktiveret plugin"; 
$LANG['crontask'][62]="Emner"; 

$LANG['devices'][0]="Tilføj en ny komponent"; 
$LANG['devices'][1]="Harddisk"; 
$LANG['devices'][2]="Grafikkort"; 
$LANG['devices'][3]="Netværkskort"; 
$LANG['devices'][4]="Processor"; 
$LANG['devices'][5]="Bundkort"; 
$LANG['devices'][6]="Hukommelse"; 
$LANG['devices'][7]="Lydkort"; 
$LANG['devices'][19]="Drev"; 
$LANG['devices'][20]="Kontrollere"; 
$LANG['devices'][21]="Andre komponenter"; 
$LANG['devices'][22]="Kabinet"; 
$LANG['devices'][23]="Strømforsyning"; 
$LANG['devices'][24]="som standard"; 
$LANG['devices'][25]="Tilføj en komponent"; 
$LANG['devices'][26]="Slet en komponent"; 

$LANG['device_case'][0]="Størrelse"; 

$LANG['device_control'][0]="RAID"; 

$LANG['device_drive'][0]="Skrive muligheder"; 
$LANG['device_drive'][1]="Hastighed"; 

$LANG['device_hdd'][0]="Rpm"; 
$LANG['device_hdd'][1]="Cache"; 
$LANG['device_hdd'][4]="Kapacitet"; 

$LANG['device_iface'][0]="Hastighed"; 
$LANG['device_iface'][2]="Mac-adresse"; 

$LANG['device_moboard'][0]="Chipset"; 

$LANG['device_power'][0]="Strøm"; 
$LANG['device_power'][1]="ATX"; 

$LANG['device_ram'][1]="Frekvens"; 
$LANG['device_ram'][2]="Størrelse"; 

$LANG['document'][1]="Checksum (SHA1)"; 
$LANG['document'][2]="Fil"; 
$LANG['document'][3]="Overskrift"; 
$LANG['document'][4]="MIME Type"; 
$LANG['document'][7]="Dokument type"; 
$LANG['document'][9]="Efternavn"; 
$LANG['document'][10]="Ikon"; 
$LANG['document'][11]="Godkend download"; 
$LANG['document'][15]="Download"; 
$LANG['document'][16]="Tilføj et dokument"; 
$LANG['document'][18]="Dokument"; 
$LANG['document'][19]="Tilhørende enheder"; 
$LANG['document'][21]="Tilhørende dokumenter"; 
$LANG['document'][22]="Nuværende fil"; 
$LANG['document'][23]="File too large to be added."; 
$LANG['document'][24]="Filen blev slettet"; 
$LANG['document'][25]="Kunne ikke slette filen"; 
$LANG['document'][26]="Filen er gyldig. Upload lykkedes"; 
$LANG['document'][27]="Potetiel upload angreb, eller filen er for stor. Flytning af temp fil mislykkedes."; 
$LANG['document'][28]="Ingen fil angivet."; 
$LANG['document'][29]="Kunne ikke oprette biblioteket"; 
$LANG['document'][30]="Kontrollér om du har de rigtige rettigheder"; 
$LANG['document'][31]="Mappe til dokumenter eksisterer ikke"; 
$LANG['document'][32]="Fil type ikke godkendt"; 
$LANG['document'][33]="Web link"; 
$LANG['document'][34]="Opret biblioteket"; 
$LANG['document'][35]="Upload bibliotek eksisterer ikke."; 
$LANG['document'][36]="Brug en ftp installeret fil."; 
$LANG['document'][37]="Ingen filer tilgængelig"; 
$LANG['document'][38]="Fil ikke fundet"; 
$LANG['document'][39]="Dokumentet er blevet flyttet"; 
$LANG['document'][40]="Fil flytning fejlet"; 
$LANG['document'][41]="Dokumentet er blevet kopieret"; 
$LANG['document'][42]="Tilføjet af"; 
$LANG['document'][43]="Ukendt fil"; 
$LANG['document'][44]="Ugyldig filnavn"; 
$LANG['document'][45]="Adgang til denne fil ikke godkendt."; 
$LANG['document'][46]="Kunne ikke sende filen (sandsynligvis for stor)"; 
$LANG['document'][48]="Et dokument eksisterer allerede med denne fil"; 
$LANG['document'][49]="Filen er ændret (forkert checksum)"; 
$LANG['document'][50]="Vedhæftede emner"; 

$LANG['entity'][0]="Entitet"; 
$LANG['entity'][2]="Rod-entitet"; 
$LANG['entity'][3]="Associér med en enhed"; 
$LANG['entity'][5]="Automatisk computer tildeling"; 
$LANG['entity'][6]="Automatisk bruger tildeling"; 
$LANG['entity'][7]="Træstruktur"; 
$LANG['entity'][8]="Pr. entitet"; 
$LANG['entity'][9]="Under-entiteter"; 
$LANG['entity'][10]="Vælg den ønskede entitet"; 
$LANG['entity'][11]="to see the entity and its sub-entities"; 
$LANG['entity'][12]="LDAP attribute identifying entity"; 
$LANG['entity'][13]="TAG identifying entity"; 
$LANG['entity'][14]="Avancerede oplysninger"; 
$LANG['entity'][15]="Entitets LDAP bibliotek"; 
$LANG['entity'][16]="Søgefilter (hvis nødvendigt)"; 
$LANG['entity'][17]="Konfiguration af automatisk lukning"; 
$LANG['entity'][18]="Automatisk lukning af sager efter"; 

$LANG['event'][0]="Kilde"; 
$LANG['event'][2]="Service"; 
$LANG['event'][3]="Level"; 
$LANG['event'][4]="Besked"; 
$LANG['event'][18]="Felt"; 
$LANG['event'][19]="Opdatering"; 
$LANG['event'][20]="Ingen historik"; 

$LANG['financial'][1]="Kontrakt"; 
$LANG['financial'][2]="Livslang"; 
$LANG['financial'][3]="Finans information"; 
$LANG['financial'][4]="Nummer"; 
$LANG['financial'][5]="Pris"; 
$LANG['financial'][6]="Kontrakt Type"; 
$LANG['financial'][8]="Varighed"; 
$LANG['financial'][9]="År"; 
$LANG['financial'][10]="Bemærkning"; 
$LANG['financial'][11]="Faktura periode"; 
$LANG['financial'][13]="Konto nummer"; 
$LANG['financial'][14]="Oversigt over køb"; 
$LANG['financial'][15]="Garanti varighed"; 
$LANG['financial'][16]="Garanti information"; 
$LANG['financial'][18]="Order nr."; 
$LANG['financial'][19]="Leverings form"; 
$LANG['financial'][20]="Immobilization nummer"; 
$LANG['financial'][21]="Værdi"; 
$LANG['financial'][22]="Afskrivnings Type"; 
$LANG['financial'][23]="Afskrivnings varighed"; 
$LANG['financial'][24]="Tilføj en kontakt..."; 
$LANG['financial'][25]="Tilføj leverandør..."; 
$LANG['financial'][26]="Leverandør"; 
$LANG['financial'][30]="Fax"; 
$LANG['financial'][33]="Tilføj en kontakt"; 
$LANG['financial'][36]="Tilføj en kontrakt"; 
$LANG['financial'][42]="Reklame"; 
$LANG['financial'][43]="Tekniker"; 
$LANG['financial'][44]="Adresse"; 
$LANG['financial'][45]="Hjemmeside"; 
$LANG['financial'][46]="Afskrivnings kontakter"; 
$LANG['financial'][47]="Lineær"; 
$LANG['financial'][48]="Degressive"; 
$LANG['financial'][50]="Lån"; 
$LANG['financial'][51]="Leje"; 
$LANG['financial'][52]="Leje"; 
$LANG['financial'][53]="Forsikring"; 
$LANG['financial'][54]="Hardware Support"; 
$LANG['financial'][55]="Software Support"; 
$LANG['financial'][56]="Service udbyder"; 
$LANG['financial'][57]="måned"; 
$LANG['financial'][59]="Behandlings timer"; 
$LANG['financial'][60]="i uge"; 
$LANG['financial'][61]="På Lørdag"; 
$LANG['financial'][62]="Søndag og helligdage"; 
$LANG['financial'][65]="Tilknyttede leverandører"; 
$LANG['financial'][66]="Afskrivnings kontrakter"; 
$LANG['financial'][68]="Aktiver finans information"; 
$LANG['financial'][69]="Kontrakt periode"; 
$LANG['financial'][76]="Start dato"; 
$LANG['financial'][77]="Afskrivnings sats"; 
$LANG['financial'][78]="Slut garanti værdi"; 
$LANG['financial'][79]="Tredieparts typer"; 
$LANG['financial'][80]="Garantien udløber"; 
$LANG['financial'][81]="Konto netto værdi"; 
$LANG['financial'][82]="Faktura nr."; 
$LANG['financial'][83]="Max antal emner"; 
$LANG['financial'][84]="Finans informationerne for dette emne er kun en model for de emner du burde tilføje"; 
$LANG['financial'][85]="Det ønskede emne blev ikke fundet"; 
$LANG['financial'][86]="Kontrakt-slut"; 
$LANG['financial'][87]="Budget"; 
$LANG['financial'][88]="Udløber den:"; 
$LANG['financial'][89]="TCO ( værdi + forsendelses pris )"; 
$LANG['financial'][90]="Månedlig TCO"; 
$LANG['financial'][91]="TCO"; 
$LANG['financial'][92]="ANV"; 
$LANG['financial'][93]="Kontrakt udløber - sidste 30 dage"; 
$LANG['financial'][94]="Kontrakt udløber om mindre end 7 dage"; 
$LANG['financial'][95]="Kontrakt udløber om mindre end 30 dage"; 
$LANG['financial'][96]="Kontrakt hvor bemærkning begynder om mindre end 7 dage"; 
$LANG['financial'][97]="Kontrakt hvor bemærkning begynder om mindre end 30 dage"; 
$LANG['financial'][98]="Slut dato"; 
$LANG['financial'][99]="Sidste Dato + bemærkning"; 
$LANG['financial'][100]="Postnr."; 
$LANG['financial'][101]="By"; 
$LANG['financial'][102]="Stat"; 
$LANG['financial'][103]="Land"; 
$LANG['financial'][104]="Tilhørende enheder"; 
$LANG['financial'][105]="Tacit"; 
$LANG['financial'][106]="Ekspress"; 
$LANG['financial'][107]="Fornyelse"; 
$LANG['financial'][108]="Totalt brugt på budget"; 
$LANG['financial'][109]="Totalt tilbage på budget"; 
$LANG['financial'][110]="Budgetter"; 

$LANG['gmt'][0]="GMT"; 
$LANG['gmt'][1]="time(r)"; 
$LANG['gmt'][2]="t"; 

$LANG['help'][1]="Matrix for beregning af prioritet"; 
$LANG['help'][2]="Major"; 
$LANG['help'][3]="Meget høj"; 
$LANG['help'][4]="Høj"; 
$LANG['help'][5]="Mellem"; 
$LANG['help'][6]="Lav"; 
$LANG['help'][7]="Meget lav"; 
$LANG['help'][8]="Informer mig om løsningerne."; 
$LANG['help'][11]="Min E-mail."; 
$LANG['help'][14]="Send besked"; 
$LANG['help'][16]="Hvis du ønsker at få besked om de handlinger der er foretaget, indtast venligst din e-mail adresse."; 
$LANG['help'][18]="Din besked er sendt korrekt, din forespørgsel er arkiveret."; 
$LANG['help'][19]="Tak fordi du brugte vores automatiske helpdesk system."; 
$LANG['help'][22]="Søg på computer id."; 
$LANG['help'][23]="Indtast det første bogstav (bruger, emnenavn, serienr. eller assetnr.)"; 
$LANG['help'][24]="Hardware Type"; 
$LANG['help'][25]="Computer"; 
$LANG['help'][26]="Netværks enhed"; 
$LANG['help'][27]="Printer"; 
$LANG['help'][28]="Skærm"; 
$LANG['help'][29]="Enhed"; 
$LANG['help'][30]="Generelt"; 
$LANG['help'][31]="Software"; 
$LANG['help'][35]="Telefon"; 
$LANG['help'][40]="Ingen titel på din sag, prøv venligst igen."; 
$LANG['help'][41]="Ingen kategori i din sag, prøv venligst igen."; 
$LANG['help'][42]="Meget høj"; 
$LANG['help'][43]="Høj"; 
$LANG['help'][44]="Mellem"; 
$LANG['help'][45]="Lav"; 
$LANG['help'][46]="Meget lav"; 
$LANG['help'][47]="Meget høj"; 
$LANG['help'][48]="Høj"; 
$LANG['help'][49]="Mellem"; 
$LANG['help'][50]="Lav"; 
$LANG['help'][51]="Meget lav"; 

$LANG['install'][0]="Installation eller opdatering af GLPI"; 
$LANG['install'][1]="Vælg 'Installation' for en helt ny installation af GLPI."; 
$LANG['install'][2]="Vælg 'Opdater' for at opdatere din version af GLPI fra en tidligere version"; 
$LANG['install'][3]="Installation"; 
$LANG['install'][4]="Opdater"; 
$LANG['install'][5]="Checker kombatibiliteten af dit miljø med kørslen af GLPI"; 
$LANG['install'][6]="Test færdig"; 
$LANG['install'][7]="Resultater"; 
$LANG['install'][8]="Tester PHP Parser"; 
$LANG['install'][9]="Du skal installere minimum PHP5."; 
$LANG['install'][10]="GLPI er ikke kompatibel med indstillingen: zend.ze1_compatibility_mode = On."; 
$LANG['install'][11]="PHP version er mindst 5.x - Perfekt !"; 
$LANG['install'][12]="Session test"; 
$LANG['install'][13]="Din PHP parser blev ikke kompilere med session support !"; 
$LANG['install'][14]="Session support er tilgængelig - Perfekt !"; 
$LANG['install'][15]="Vær sikker på at session support er blevet aktiveret i php.inin"; 
$LANG['install'][16]="Checker skriverettigheder for dump filer"; 
$LANG['install'][17]="Filen kunne ikke oprettes"; 
$LANG['install'][18]="Uofficielle oversættelser er også tilgængelige"; 
$LANG['install'][19]="Filen blev oprettet men kan ikke slettes."; 
$LANG['install'][20]="En fil og en mappe er oprettet og slettet - Perfekt !"; 
$LANG['install'][21]="Checker skrive rettigheder for dokument filer"; 
$LANG['install'][22]="En fil blev oprettet - perfekt!"; 
$LANG['install'][23]="Checker skriverettigheder for indstillings filerne"; 
$LANG['install'][24]="Initialisere databasen"; 
$LANG['install'][25]="Fortsæt ?"; 
$LANG['install'][26]="Fortsæt"; 
$LANG['install'][27]="Prøv igen."; 
$LANG['install'][28]="Databaseforbindelse opsætning"; 
$LANG['install'][29]="Database forbindelses parametre"; 
$LANG['install'][30]="Mysql server"; 
$LANG['install'][31]="Mysql bruger"; 
$LANG['install'][32]="Mysql kodeord"; 
$LANG['install'][34]="Test af forbindelsen til databasen"; 
$LANG['install'][35]="Kan ikke forbinde til databasen"; 
$LANG['install'][36]="Serveren svarede"; 
$LANG['install'][37]="Server og/eller bruger feltet er tomt"; 
$LANG['install'][38]="Vær venlig at vælg en database:"; 
$LANG['install'][39]="Opret en ny database eller brug en eksisterende:"; 
$LANG['install'][40]="Vær venlig at vælgt databasen der skal opdateres:"; 
$LANG['install'][41]="Umuligt at bruge databasen:"; 
$LANG['install'][43]="OK - Databasen blev initialiseret"; 
$LANG['install'][47]="Umuligt at skrive til database opsætningsfilen"; 
$LANG['install'][48]="Fejl ved oprettelse af database !"; 
$LANG['install'][49]="Du har ikke valgt en database"; 
$LANG['install'][50]="Checker skriverettigheder for session filer"; 
$LANG['install'][52]="Kontrollér skriverettigheder for automatiske hændelser-filer"; 
$LANG['install'][53]="Kontrollerer skriverettigheder for logfiler"; 
$LANG['install'][55]="Installationen er færdig"; 
$LANG['install'][57]="Standard brugernavne / kodeord er:"; 
$LANG['install'][58]="glpi/glpi for administrator kontoen"; 
$LANG['install'][59]="tech/tech for den tekniske konto"; 
$LANG['install'][60]="normal/normal for den normale konto"; 
$LANG['install'][61]="post-only/postonly for brugeren der kun har skriverettigheder"; 
$LANG['install'][62]="Du kan slette eller ændre disse konti, såvel som opstarts-data."; 
$LANG['install'][64]="Brug GLPI"; 
$LANG['install'][65]="magic_quotes_sybase extension test"; 
$LANG['install'][66]="GLPI virker ikke med magic_quotes_sybase option ; Vær venlig at slukke den og prøve igen."; 
$LANG['install'][67]="magic_quotes_sybase optionen er ikke aktiveret på din server - Perfekt !"; 
$LANG['install'][68]="Test session autostart"; 
$LANG['install'][69]="session.auto_start er aktiveret. Se .htaccess filen i GLPI roden for yderligere information."; 
$LANG['install'][70]="Kan ikke lave database connection filen, vær venlig at kontrollér fil tilladelserne."; 
$LANG['install'][71]="Mysql test"; 
$LANG['install'][72]="Du skal kompilere din php med Mysql udvidelsen"; 
$LANG['install'][73]="Ok - funktionen mysql_query() eksisterer - Perfekt !"; 
$LANG['install'][74]="Test om Session_use_trans_sid er i brug"; 
$LANG['install'][75]="Du skal deaktivere Session_use_trans_id funktionen i din php.ini"; 
$LANG['install'][76]="Ok- Sessionen virker ( ingen problemer med trans_id) - Perfekt !"; 
$LANG['install'][77]="Trin"; 
$LANG['install'][81]="Begyndelse af installationen"; 
$LANG['install'][82]="Database oprettet"; 
$LANG['install'][85]="Funktionnaliteten blev fundet - Perfekt !"; 
$LANG['install'][86]="Allokeret hukommelse test"; 
$LANG['install'][87]="Allokeret hukommelse:"; 
$LANG['install'][88]="Minimum 64MB er normalt nødvendigt til GLPI."; 
$LANG['install'][89]="Perfekt !"; 
$LANG['install'][90]="Prøv og forøg memory_limit parameteren i php.ini filen."; 
$LANG['install'][91]="Allokeret hukommelse > 64M"; 
$LANG['install'][92]="Licens"; 
$LANG['install'][93]="Jeg har læst og accepterer betingelser og licensen som skrevet ovenfor."; 
$LANG['install'][94]="Jeg har læst og accepterer IKKE betingelserne af den ovenstående licens."; 
$LANG['install'][95]="Ubegrænset hukommelse"; 
$LANG['install'][96]="Ubegrænset hukommelse"; 
$LANG['install'][97]="Kontrollér rettigheder til mappen:"; 
$LANG['install'][99]="Checker skrive rettigheder for cache filer"; 
$LANG['install'][100]="Mappen kunne ikke oprettes."; 
$LANG['install'][101]="Mappen blev oprettet, men kunne ikke fjernes."; 
$LANG['install'][102]="Test json funktioner"; 
$LANG['install'][103]="GLPI kan ikke fungere korrekt uden json_encode og json_decode funktionerne"; 
$LANG['install'][104]="mbstring udvidelses-test"; 
$LANG['install'][105]="Mbstring udvidelsen til din PHP fortolker er ikke installeret"; 
$LANG['install'][106]="Kontrollerer skriverettigheder for grafikfiler"; 

$LANG['job'][2]="af"; 
$LANG['job'][4]="Forespørger"; 
$LANG['job'][5]="Tildelt til"; 
$LANG['job'][6]="Teknikker"; 
$LANG['job'][7]="Opgave"; 
$LANG['job'][8]="sidste sag(er)"; 
$LANG['job'][9]="Opfølgning"; 
$LANG['job'][11]="Beskriv problemet/løsningen"; 
$LANG['job'][12]="Ingen opfølgning for denne sag."; 
$LANG['job'][13]="Ny sag"; 
$LANG['job'][15]="Løst"; 
$LANG['job'][19]="E-mail opfølgninger"; 
$LANG['job'][20]="Samlet varighed"; 
$LANG['job'][21]="Time(r)"; 
$LANG['job'][22]="Minuter"; 
$LANG['job'][29]="Tilføj en ny opfølgning"; 
$LANG['job'][30]="Tilføj en ny opgave"; 
$LANG['job'][31]="Varighed"; 
$LANG['job'][32]="Ingen"; 
$LANG['job'][33]="Tom beskrivelse"; 
$LANG['job'][34]="Planlæg denne opgave"; 
$LANG['job'][35]="Planlægning"; 
$LANG['job'][37]="Resume"; 
$LANG['job'][38]="Sag"; 
$LANG['job'][39]="Opdater opfølgning"; 
$LANG['job'][40]="Time pris"; 
$LANG['job'][41]="Fast pris"; 
$LANG['job'][42]="Materiale pris"; 
$LANG['job'][43]="Samlet pris"; 
$LANG['job'][44]="Ønsket kilde"; 
$LANG['job'][45]="Kilde til opfølgning"; 
$LANG['job'][46]="Sagen vil blive tilføjet i entiteten"; 
$LANG['job'][47]="Costs"; 
$LANG['job'][48]="Løsnings-type"; 
$LANG['job'][49]="Ny opgave"; 
$LANG['job'][50]="Ingen opgaver for denne sag"; 
$LANG['job'][51]="Godkendelse af løsning"; 
$LANG['job'][52]="Opdatér opgave"; 
$LANG['job'][53]="Sletning af en opgave"; 
$LANG['job'][54]="Uden et svar, vil sagen automatisk blive lukket efter"; 

$LANG['joblist'][0]="Status"; 
$LANG['joblist'][1]="Kun mine!"; 
$LANG['joblist'][2]="Prioritet"; 
$LANG['joblist'][3]="Personlig + gruppe(r)"; 
$LANG['joblist'][4]="Tildelt"; 
$LANG['joblist'][6]="Beskrivelse"; 
$LANG['joblist'][7]="Nyt sag for dette emne..."; 
$LANG['joblist'][8]="Ingen sag fundet"; 
$LANG['joblist'][9]="Ny"; 
$LANG['joblist'][10]="Lukket (løst)"; 
$LANG['joblist'][11]="Åbnet den"; 
$LANG['joblist'][12]="Lukket den"; 
$LANG['joblist'][13]="Sager der skal behandles"; 
$LANG['joblist'][14]="Løst den"; 
$LANG['joblist'][16]="Ingen aktive sager"; 
$LANG['joblist'][17]="Lukket (ikke løst)"; 
$LANG['joblist'][18]="Behandler (tildelt)"; 
$LANG['joblist'][19]="Behandler (planlagt)"; 
$LANG['joblist'][21]="Behandler"; 
$LANG['joblist'][26]="Afventer"; 
$LANG['joblist'][27]="E-mail til opfølgning"; 
$LANG['joblist'][28]="Sager på linkede emner"; 
$LANG['joblist'][29]="Vigtighed"; 
$LANG['joblist'][30]="Påvirkning"; 
$LANG['joblist'][32]="Løst"; 
$LANG['joblist'][33]="Lukket"; 
$LANG['joblist'][34]="Ikke løst"; 
$LANG['joblist'][35]="Ikke lukket"; 
$LANG['joblist'][36]="Status value in database"; 

$LANG['jobresolution'][1]="Løsning"; 
$LANG['jobresolution'][3]="Godkendt løsning"; 
$LANG['jobresolution'][4]="Afvist løsning"; 
$LANG['jobresolution'][5]="Hvis du afviser løsningen, skal du angive en årsag"; 

$LANG['knowbase'][1]="FAQ"; 
$LANG['knowbase'][5]="Placér dette emne i FAQ"; 
$LANG['knowbase'][6]="Vælg en kategori til dette emne"; 
$LANG['knowbase'][7]="Slet dette emne fra FAQ"; 
$LANG['knowbase'][8]="Rediger dette emne"; 
$LANG['knowbase'][9]="Slet dette"; 
$LANG['knowbase'][10]="Dette emne er en del af FAQ"; 
$LANG['knowbase'][11]="Dette emne er ikke en del af FAQ"; 
$LANG['knowbase'][12]="Root"; 
$LANG['knowbase'][13]="Kategori navn"; 
$LANG['knowbase'][14]="Emne"; 
$LANG['knowbase'][15]="Indhold"; 
$LANG['knowbase'][24]="Adgang til ofte stillede spørgsmål"; 
$LANG['knowbase'][26]="Visninger"; 
$LANG['knowbase'][27]="Tændt"; 
$LANG['knowbase'][29]="Nylige indtastninger"; 
$LANG['knowbase'][30]="Mest populære spørgsmål"; 

$LANG['ldap'][0]="Masseimportér brugere fra et LDAP bibliotek"; 
$LANG['ldap'][1]="Synkroniser allerede importerede brugere"; 
$LANG['ldap'][2]="Importer nye brugere"; 
$LANG['ldap'][3]="Ingen brugere at importere"; 
$LANG['ldap'][4]="LDAP bibliotek valg"; 
$LANG['ldap'][5]="Vælg det LDAP katalog du vil importere brugere fra"; 
$LANG['ldap'][6]="Kan ikke forbinde til LDAP bibliotek"; 
$LANG['ldap'][7]="Intet LDAP bibliotek defineret i GLPI"; 
$LANG['ldap'][8]="Advarsel: Forespørgslen overskrider grænserne for biblioteket. Resultatet er kun delvist."; 
$LANG['ldap'][9]="Test af forbindelse til LDAP katalog"; 
$LANG['ldap'][12]="Synkronering"; 
$LANG['ldap'][13]="i LDAP biblioteket"; 
$LANG['ldap'][14]="i GLPI"; 
$LANG['ldap'][15]="Synkroniser"; 
$LANG['ldap'][16]="Preconfiguration"; 
$LANG['ldap'][17]="Active Directory"; 
$LANG['ldap'][18]="List of LDAP directory replicates"; 
$LANG['ldap'][19]="Replikér"; 
$LANG['ldap'][20]="Tilføj en LDAP bibliotek replika"; 
$LANG['ldap'][21]="Primær server"; 
$LANG['ldap'][22]="Replika(er)"; 
$LANG['ldap'][23]="Masse-importér grupper fra LDAP biblioteket"; 
$LANG['ldap'][24]="Import af nye grupper"; 
$LANG['ldap'][25]="Ingen grupper at importere"; 
$LANG['ldap'][30]="Hvordan LDAP aliaser skal håndteres"; 
$LANG['ldap'][31]="Never dereferenced (default)"; 
$LANG['ldap'][32]="Always dereferenced"; 
$LANG['ldap'][33]="Dereferenced during the search (but not when locating)"; 
$LANG['ldap'][34]="Dereferenced when locating (not during the search)"; 
$LANG['ldap'][35]="Importér en bruger"; 
$LANG['ldap'][36]="No directory associated to entity : search impossible"; 
$LANG['ldap'][38]="Søgekriterier for brugere"; 
$LANG['ldap'][39]="Avanceret"; 
$LANG['ldap'][40]="Simpel"; 
$LANG['ldap'][41]="For at ændre"; 
$LANG['ldap'][42]="Intet bibliotek valgt"; 
$LANG['ldap'][43]="Ingen brugere til synkronisering"; 
$LANG['ldap'][44]="Standard server"; 
$LANG['ldap'][45]="Handling, når en bruger slettes fra LDAP biblioteket"; 
$LANG['ldap'][46]="Withdraw accreditations and groups (dynamics)"; 
$LANG['ldap'][47]="Put in trash"; 
$LANG['ldap'][48]="Slettet bruger i LDAP bibliotek"; 
$LANG['ldap'][49]="Vis brugere tilføjet siden"; 
$LANG['ldap'][50]="Vis brugere opdateret siden"; 
$LANG['ldap'][52]="Mindre end"; 
$LANG['ldap'][53]="Mere end"; 
$LANG['ldap'][54]="Aktivér filtrering efter dato"; 
$LANG['ldap'][55]="Deaktivér filtrering efter dato"; 
$LANG['ldap'][56]="Uger"; 

$LANG['links'][1]="Link eller filnavn"; 
$LANG['links'][4]="Tilhørende hardware type"; 
$LANG['links'][6]="Gyldige tags"; 
$LANG['links'][7]="Ingen link er defineret"; 
$LANG['links'][9]="Fil inhold"; 

$LANG['log'][1]="system"; 
$LANG['log'][16]="planlægning"; 
$LANG['log'][18]="komonenter"; 
$LANG['log'][20]="emne tilføjet"; 
$LANG['log'][21]="opdater emne"; 
$LANG['log'][22]="Slet"; 
$LANG['log'][23]="gendan emne"; 
$LANG['log'][24]="slet emne"; 
$LANG['log'][26]="frakobl emne"; 
$LANG['log'][27]="emne forbindelse"; 
$LANG['log'][28]="opdater komponenter"; 
$LANG['log'][29]="godkendelse/afvisning af løsning"; 
$LANG['log'][30]="Tildel en type"; 
$LANG['log'][31]="Slet en type"; 
$LANG['log'][32]="tilføj et link med en ting"; 
$LANG['log'][33]="Slet link med"; 
$LANG['log'][34]="Tilføj link til leverandør"; 
$LANG['log'][35]="Slet link til leverandør"; 
$LANG['log'][40]="IP forbindelse"; 
$LANG['log'][41]="Forbindelse fejlet"; 
$LANG['log'][42]="Resevation"; 
$LANG['log'][44]="Overskrift"; 
$LANG['log'][45]="Successfull"; 
$LANG['log'][46]="Fejlet"; 
$LANG['log'][48]="Tilføj bruger til gruppe"; 
$LANG['log'][49]="Slet brugeren fra gruppen"; 
$LANG['log'][55]="Forbindelse"; 
$LANG['log'][59]="Automatisk hændelse"; 
$LANG['log'][60]="brug enheds håndtering for dette emne"; 
$LANG['log'][61]="tilføjer bruger til entitet"; 
$LANG['log'][62]="sletning af bruger fra entitet"; 
$LANG['log'][64]="ændring af et felt"; 
$LANG['log'][65]="regel"; 
$LANG['log'][66]="Sikkerhed"; 
$LANG['log'][67]="ændring af noter"; 
$LANG['log'][70]="netværksport tilføjet"; 
$LANG['log'][71]="flere netværksporte tilføjet"; 
$LANG['log'][73]="sletning af en netværksport"; 
$LANG['log'][74]="sletning af flere netværksporte"; 
$LANG['log'][75]="netværksport flyttet"; 
$LANG['log'][77]="tilknytning af et vlan til en netværksport"; 
$LANG['log'][78]="tilknytning af et vlan til flere porte"; 
$LANG['log'][79]="fjernet vlan tilknytning fra en netværksport"; 
$LANG['log'][80]="fjernelse af tilknytning til et VLAN fra flere netværksporte"; 
$LANG['log'][82]="tilføjer version"; 
$LANG['log'][83]="ændring af version"; 
$LANG['log'][84]="sletning af version"; 
$LANG['log'][85]="tilføjer licens"; 
$LANG['log'][86]="ændring af licens"; 
$LANG['log'][87]="sletning af licens"; 
$LANG['log'][88]="tilføjer patroner"; 
$LANG['log'][89]="tilføjer forbrugsvarer"; 
$LANG['log'][90]="sletning af en patron"; 
$LANG['log'][91]="sletning af forbrugsvare"; 
$LANG['log'][92]="restoration of a cartridge"; 
$LANG['log'][93]="restoration of a consumable"; 
$LANG['log'][94]="opdatering af patron"; 
$LANG['log'][95]="installation af patron"; 
$LANG['log'][96]="fjernelse af patron"; 
$LANG['log'][97]="consumable out for the user"; 
$LANG['log'][98]="tilføj et emne"; 
$LANG['log'][99]="ændring af et emne"; 
$LANG['log'][100]="sletning af et emne"; 

$LANG['login'][0]="Sidste login"; 
$LANG['login'][1]="Log ind igen"; 
$LANG['login'][2]="LDAP bibliotek"; 
$LANG['login'][3]="IMAP/POP"; 
$LANG['login'][4]="CAS"; 
$LANG['login'][5]="Adgang nægtet"; 
$LANG['login'][6]="Bruger navn"; 
$LANG['login'][7]="Kode"; 
$LANG['login'][8]="Tom login eller kode"; 
$LANG['login'][9]="Endnu ikke autentificeret"; 
$LANG['login'][10]="Godkendelse"; 
$LANG['login'][11]="Ikke tilladt bruger at bruge GLPI"; 
$LANG['login'][12]="forkert brugernavn eller kode"; 
$LANG['login'][13]="Adgangskode feltet er tomt"; 
$LANG['login'][14]="ukendt bruger"; 
$LANG['login'][15]="Bruger ikke fundet eller flere brugere fundet"; 
$LANG['login'][16]="fejlet godkendelse i LDAP"; 
$LANG['login'][18]="Base intern GLPI"; 
$LANG['login'][20]="Du har ikke adgang til denne applikation da din konto er deaktiveret eller fjernet"; 
$LANG['login'][21]="Test forbindelsen til IMAP/POP server"; 
$LANG['login'][22]="Succes!"; 
$LANG['login'][23]="Testen fejlede"; 
$LANG['login'][24]="Dato for sidste login"; 
$LANG['login'][25]="Du har ikke tilladelse til at tilslutte"; 
$LANG['login'][26]="Du skal aktivere JavaScript i din browser"; 
$LANG['login'][27]="Du skal acceptere cookies for at nå denne applikation"; 
$LANG['login'][30]="Ændring af godkendelsesmetode"; 
$LANG['login'][31]="Godkendelse i et LDAP bibliotek"; 
$LANG['login'][32]="Godkendelse i GLPI databasen"; 
$LANG['login'][33]="Godkendelse på IMAP/POP server"; 

$LANG['mailgate'][0]="Mail-modtager"; 
$LANG['mailgate'][2]="Get email tickets now"; 
$LANG['mailgate'][3]="Number of available and retrieved emails"; 
$LANG['mailgate'][4]="mbstring extension not found. Warning with charsets used."; 
$LANG['mailgate'][5]="Invalid attached file"; 
$LANG['mailgate'][6]="Vedhæftet fil er for stor"; 
$LANG['mailgate'][7]="Maximum size of each file imported by the mail receiver"; 
$LANG['mailgate'][9]="Din e-mail kunne ikke behandles.\nHvis problemet fortsætter, kontakt da administratoren"; 
$LANG['mailgate'][10]="Email afvist"; 
$LANG['mailgate'][11]="Process of emails import"; 
$LANG['mailgate'][12]="Unable to affect the email to an entity"; 
$LANG['mailgate'][13]="Reason of rebuff"; 
$LANG['mailgate'][14]="Email ikke fundet. Umuligt at importere"; 
$LANG['mailgate'][16]="Re:"; 

$LANG['mailing'][0]="----------------------------------------------------------"; 
$LANG['mailing'][1]="======================================================================"; 
$LANG['mailing'][4]="Allerede lavede opfølgninger"; 
$LANG['mailing'][5]="Beskrivelse af sagen"; 
$LANG['mailing'][10]="Ny sags-opfølgning"; 
$LANG['mailing'][12]="Sag tildelt til"; 
$LANG['mailing'][14]="Opdatering af sags-kategori"; 
$LANG['mailing'][15]="Opdatering af sags-prioritet"; 
$LANG['mailing'][17]="Opdatering af sags-emne"; 
$LANG['mailing'][18]="Opdatér sagens forfatter"; 
$LANG['mailing'][19]="Ny resevation"; 
$LANG['mailing'][20]="Opdatér sagens gruppe"; 
$LANG['mailing'][21]="Ændring af sagens kilde"; 
$LANG['mailing'][23]="Resevation ændret"; 
$LANG['mailing'][26]="Tilføjet dokument :"; 
$LANG['mailing'][27]="Opdatering af sags-status"; 
$LANG['mailing'][29]="Resevation annuleret"; 
$LANG['mailing'][30]="Sag opdateret"; 
$LANG['mailing'][31]="Dette er en test mail, for at teste om mailing systemet virker"; 
$LANG['mailing'][32]="Mail test"; 
$LANG['mailing'][33]="Patron alarm"; 
$LANG['mailing'][35]="Threshold of alarm reached for the type of consumable:"; 
$LANG['mailing'][36]="Forbrugs alarm"; 
$LANG['mailing'][37]="Kontrakt indtastet i bemærknings tid:"; 
$LANG['mailing'][39]="Kontrakt Alarm"; 
$LANG['mailing'][40]="Emner ankommet efter garanti:"; 
$LANG['mailing'][41]="Finans alarm"; 
$LANG['mailing'][42]="Ændring i time-omkostninger"; 
$LANG['mailing'][43]="Ændring i faste omkostninger"; 
$LANG['mailing'][44]="Ændring i materiale pris"; 
$LANG['mailing'][45]="Skift sagens titel"; 
$LANG['mailing'][46]="Skift sagens beskrivelse"; 
$LANG['mailing'][47]="Fejl ved afsendelse af email"; 
$LANG['mailing'][48]="Ændring i åbningsdato"; 
$LANG['mailing'][49]="Ændring i lukningsdato"; 
$LANG['mailing'][50]="Skift sagens modtager"; 
$LANG['mailing'][51]="Udløbet licens :"; 
$LANG['mailing'][53]="Ændring af løsning"; 
$LANG['mailing'][54]="Udløbsdato"; 
$LANG['mailing'][100]="Ikke defineret en katagori"; 
$LANG['mailing'][101]="E-mail opfølgning er slået til"; 
$LANG['mailing'][102]="E-mail opfølgning er slået fra"; 
$LANG['mailing'][104]="Opfølgnings varighed"; 
$LANG['mailing'][105]="Ikke tildelt"; 
$LANG['mailing'][107]="Intet"; 
$LANG['mailing'][109]="Ingen gruppe"; 
$LANG['mailing'][110]="Ugyldig email"; 
$LANG['mailing'][113]="Påmindelsesskabeloner"; 
$LANG['mailing'][114]="Body"; 
$LANG['mailing'][115]="Main part of email"; 
$LANG['mailing'][116]="HTML"; 
$LANG['mailing'][117]="tekst"; 
$LANG['mailing'][118]="Email"; 
$LANG['mailing'][119]="Forekomst"; 
$LANG['mailing'][120]="Påmindelses metode"; 
$LANG['mailing'][121]="Modtagere"; 
$LANG['mailing'][122]="Task(s) already done"; 
$LANG['mailing'][123]="Løste sager"; 
$LANG['mailing'][124]="Tilføj en ny oversættelse"; 
$LANG['mailing'][125]="Standard oversættelse"; 
$LANG['mailing'][126]="Skabelon-oversættelse"; 
$LANG['mailing'][127]="Lukning af sagen"; 
$LANG['mailing'][128]="leave the field empty for a generation from HTML"; 
$LANG['mailing'][129]="Sletning af sag"; 
$LANG['mailing'][130]="Fra"; 
$LANG['mailing'][131]="Modtager"; 
$LANG['mailing'][132]="Email header"; 
$LANG['mailing'][133]="Slet email(s)"; 
$LANG['mailing'][134]="Opdaterer opfølgning"; 
$LANG['mailing'][135]="Opfølgning sletning"; 
$LANG['mailing'][136]="Reservation udløbet"; 
$LANG['mailing'][137]="Hardware bruger"; 
$LANG['mailing'][138]="Liste over tilgængelige mærker"; 
$LANG['mailing'][139]="Mærkat"; 
$LANG['mailing'][140]="Mærke"; 
$LANG['mailing'][141]="Opfølgninger"; 
$LANG['mailing'][142]="Opgaver"; 
$LANG['mailing'][143]="Valideringer"; 
$LANG['mailing'][144]="Historik"; 
$LANG['mailing'][145]="List of values"; 
$LANG['mailing'][146]="Énkelt værdi"; 
$LANG['mailing'][147]="Mulige værdier"; 

$LANG['Menu'][0]="Computere"; 
$LANG['Menu'][1]="Netværk"; 
$LANG['Menu'][2]="Printere"; 
$LANG['Menu'][3]="Skærme"; 
$LANG['Menu'][4]="Software"; 
$LANG['Menu'][5]="Sager"; 
$LANG['Menu'][6]="Rapporter"; 
$LANG['Menu'][11]="Indstillinger"; 
$LANG['Menu'][12]="Vedligehold"; 
$LANG['Menu'][13]="Statistik"; 
$LANG['Menu'][14]="Brugere"; 
$LANG['Menu'][15]="Administration"; 
$LANG['Menu'][16]="Enheder"; 
$LANG['Menu'][17]="Reservationer"; 
$LANG['Menu'][18]="Værktøj"; 
$LANG['Menu'][19]="Vidensdatabase"; 
$LANG['Menu'][20]="FAQ"; 
$LANG['Menu'][21]="Patroner"; 
$LANG['Menu'][22]="Kontakter"; 
$LANG['Menu'][23]="Leverandører"; 
$LANG['Menu'][24]="Finans information"; 
$LANG['Menu'][25]="Kontrakter"; 
$LANG['Menu'][26]="Management"; 
$LANG['Menu'][27]="Dokumenter"; 
$LANG['Menu'][28]="Status"; 
$LANG['Menu'][29]="Planlægning"; 
$LANG['Menu'][30]="Logs"; 
$LANG['Menu'][31]="Simpel brugerflade"; 
$LANG['Menu'][32]="Forbrugsvarer"; 
$LANG['Menu'][33]="OCSNG"; 
$LANG['Menu'][34]="Telefoner"; 
$LANG['Menu'][35]="Profiler"; 
$LANG['Menu'][36]="Grupper"; 
$LANG['Menu'][37]="Entiteter"; 
$LANG['Menu'][38]="Inventering"; 
$LANG['Menu'][39]="Modtagere"; 
$LANG['Menu'][40]="Bogmærker"; 
$LANG['Menu'][41]="Rettigheder"; 

$LANG['monitors'][14]="Mikrofon"; 
$LANG['monitors'][15]="Højtalere"; 
$LANG['monitors'][18]="Flag"; 
$LANG['monitors'][19]="Sub-D"; 
$LANG['monitors'][20]="BNC"; 
$LANG['monitors'][21]="Størrelse"; 
$LANG['monitors'][32]="DVI"; 
$LANG['monitors'][33]="Pivot"; 

$LANG['networking'][4]="Netværksport"; 
$LANG['networking'][5]="Hukommelse (MB)"; 
$LANG['networking'][6]="Netværksport"; 
$LANG['networking'][13]="netværksporte fundet"; 
$LANG['networking'][14]="IP"; 
$LANG['networking'][15]="MAC"; 
$LANG['networking'][17]="Forbundet til"; 
$LANG['networking'][19]="Tilføj netværksport..."; 
$LANG['networking'][21]="Portnummer"; 
$LANG['networking'][25]="på"; 
$LANG['networking'][37]="Netværksport(e) fundet"; 
$LANG['networking'][44]="porten"; 
$LANG['networking'][46]="Tilføj adskillige porte..."; 
$LANG['networking'][47]="Fra"; 
$LANG['networking'][48]="Til"; 
$LANG['networking'][51]="Netværksudtag"; 
$LANG['networking'][55]="Tilknyt et Vlan"; 
$LANG['networking'][56]="VLAN"; 
$LANG['networking'][57]="Vælg en MAC-adresse på listen eller skriv den nedenfor"; 
$LANG['networking'][58]="Fjern tilknytning til et VLAN"; 
$LANG['networking'][59]="Gateway"; 
$LANG['networking'][60]="Maske"; 
$LANG['networking'][61]="Subnet"; 

$LANG['ocsconfig'][1]="OCSNG databasebruger"; 
$LANG['ocsconfig'][2]="Vært for OCSNG databasen"; 
$LANG['ocsconfig'][3]="OCSNG bruger-password"; 
$LANG['ocsconfig'][4]="Navn på OCSNG databasen"; 
$LANG['ocsconfig'][5]="Import muligheder"; 
$LANG['ocsconfig'][6]="Ignorér i OCSNG import"; 
$LANG['ocsconfig'][7]="OCSNG database in UTF8"; 
$LANG['ocsconfig'][9]="Ekskludér følgende tags (separator $, ingenting for alle)"; 
$LANG['ocsconfig'][10]="Global import"; 
$LANG['ocsconfig'][11]="Ingen import"; 
$LANG['ocsconfig'][12]="emne import"; 
$LANG['ocsconfig'][13]="Enhedsimport: alt importeres 'som det er'"; 
$LANG['ocsconfig'][14]="Global import: alt importeres men emnet er globalt håndteret (uden dubletter)"; 
$LANG['ocsconfig'][15]="Ingen import: Dette plugin vil ikke importere disse emner"; 
$LANG['ocsconfig'][16]="Standard status"; 
$LANG['ocsconfig'][17]="Begræns importen til de følgende tags ( seperator $, intet for alle )"; 
$LANG['ocsconfig'][18]="Først, check om dubletter håndteres i OCSNG"; 
$LANG['ocsconfig'][19]="Enhedsimport via serienummer"; 
$LANG['ocsconfig'][27]="Generelle informationer"; 
$LANG['ocsconfig'][36]="Modem"; 
$LANG['ocsconfig'][37]="Porte"; 
$LANG['ocsconfig'][38]="Brug OCSNG software bibliotek"; 
$LANG['ocsconfig'][39]="OCSNG TAG"; 
$LANG['ocsconfig'][40]="Antal emner der skal synkroniseres ved brug af den automatisk OCSNG handling"; 
$LANG['ocsconfig'][41]="Registreringsdatabase"; 
$LANG['ocsconfig'][43]="OCSNG Administrativ information"; 
$LANG['ocsconfig'][48]="Opførsel ved frakobling"; 
$LANG['ocsconfig'][49]="Affald"; 
$LANG['ocsconfig'][50]="Sletning"; 
$LANG['ocsconfig'][52]="Automatisk tilslutning af computere"; 
$LANG['ocsconfig'][53]="Aktivér det automatiske link"; 
$LANG['ocsconfig'][54]="Eksistenskriterie for en computer"; 
$LANG['ocsconfig'][55]="Find computere med status"; 
$LANG['ocsconfig'][56]="tom"; 
$LANG['ocsconfig'][57]="ens"; 
$LANG['ocsconfig'][58]="Linket tilknytter automatisk en GLPI computer med en i OCSNG.<br>Denne indstilling bruges ved manuel link og af synkroniserings-scripts."; 
$LANG['ocsconfig'][59]="Web-adresse for OCSNG konsollen"; 

$LANG['ocsng'][0]="OCS Inventory NG"; 
$LANG['ocsng'][1]="Synkronisér allerede importerede computere"; 
$LANG['ocsng'][2]="Importer nye computere"; 
$LANG['ocsng'][3]="Ryd links mellem GLPI og OCSNG"; 
$LANG['ocsng'][4]="Link nye OCS computere til eksisterende GLPI computere"; 
$LANG['ocsng'][5]="Importer nye computere"; 
$LANG['ocsng'][6]="Auto opdater"; 
$LANG['ocsng'][7]="Importeret fra OCSNG"; 
$LANG['ocsng'][8]="Import lykkedes"; 
$LANG['ocsng'][9]="Ingen nye computere skal importeres"; 
$LANG['ocsng'][10]="Computere opdateret i OCSNG"; 
$LANG['ocsng'][11]="Opdater computere"; 
$LANG['ocsng'][12]="Ingen nye computere skal opdateres"; 
$LANG['ocsng'][13]="Importdato i GLPI"; 
$LANG['ocsng'][14]="Sidste inventeringsdato i OCSNG"; 
$LANG['ocsng'][15]="Ingen felt er låst"; 
$LANG['ocsng'][16]="Låste felter"; 
$LANG['ocsng'][18]="Forbindelse til OCSNG databasen lykkedes"; 
$LANG['ocsng'][19]="Korrekt OCSNG konfiguration og version"; 
$LANG['ocsng'][20]="Ugyldig OCSNG version: RC3 er påkrævet"; 
$LANG['ocsng'][21]="Forbindelse til OSCNG databasen fejlede"; 
$LANG['ocsng'][22]="Forsigtig! De importerede data (se din konfiguration) vil overskrive de eksisterende data"; 
$LANG['ocsng'][23]="Kunne ikke importere, GLPI computer er allerede relateret til et emne i OCSNG"; 
$LANG['ocsng'][24]="Tvunget synkronisering"; 
$LANG['ocsng'][26]="Valg af OCSNG server"; 
$LANG['ocsng'][27]="Ingen OCSNG server er defineret"; 
$LANG['ocsng'][29]="OCSNG server"; 
$LANG['ocsng'][30]="Låst skærm(e)"; 
$LANG['ocsng'][32]="Låst enhed(er)"; 
$LANG['ocsng'][34]="Låst printer(e)"; 
$LANG['ocsng'][36]="Destinations-entitet"; 
$LANG['ocsng'][37]="Aktiver forvisning"; 
$LANG['ocsng'][38]="Deaktiver forvisning"; 
$LANG['ocsng'][40]="Pas til reglen ?"; 
$LANG['ocsng'][41]="Manuel import-tilstand"; 
$LANG['ocsng'][42]="Ugyldig OCSNG konfiguration (TRACE_DELETED skal være aktiv)"; 
$LANG['ocsng'][43]="Adgang nægtet til OCSNG databasen (Kræver skrive-rettigheder på hardware. krævet CHECKSUM)"; 
$LANG['ocsng'][44]="Adgang nægtet til OCSNG databasen (Slette-rettigheder i deleted_equiv tabellen påkrævet)"; 
$LANG['ocsng'][45]="OCS ID"; 
$LANG['ocsng'][46]="Slettet i OCSNG"; 
$LANG['ocsng'][47]="Linket til en OCSNG computer"; 
$LANG['ocsng'][48]="Computerens OCSNG ID er ændret"; 
$LANG['ocsng'][49]="Agent"; 
$LANG['ocsng'][50]="Låst IP(er)"; 
$LANG['ocsng'][52]="Låst software"; 
$LANG['ocsng'][54]="Software slettet af OCSNG synkronisering"; 
$LANG['ocsng'][55]="Låst(e) volumen(er)"; 
$LANG['ocsng'][57]="OCSNG grænseflade"; 

$LANG['pager'][1]="til"; 
$LANG['pager'][2]="fra"; 
$LANG['pager'][3]="i"; 
$LANG['pager'][4]="vis"; 
$LANG['pager'][5]="emner"; 

$LANG['peripherals'][18]="Mærke"; 
$LANG['peripherals'][31]="Global håndtering"; 
$LANG['peripherals'][32]="Emne håndtering"; 
$LANG['peripherals'][33]="Håndteringstype"; 

$LANG['phones'][18]="Mærke"; 
$LANG['phones'][36]="Strømforsyning"; 
$LANG['phones'][38]="Hjelm telefoner"; 
$LANG['phones'][39]="Højtaler"; 
$LANG['phones'][40]="Antal linier"; 

$LANG['planning'][0]="Den ønskede tekniker har allerede en aftale for dette tidspunkt"; 
$LANG['planning'][1]="Fejl i de valgte datoer. Slut dato kommer før start dato"; 
$LANG['planning'][5]="Dag"; 
$LANG['planning'][6]="Uge"; 
$LANG['planning'][8]="Sporing"; 
$LANG['planning'][9]="pr."; 
$LANG['planning'][10]="Ical"; 
$LANG['planning'][11]="Webcal"; 
$LANG['planning'][12]="Download planlægningen i Ical format"; 
$LANG['planning'][13]="Webkalender:// Synkronering"; 
$LANG['planning'][14]="Måned"; 
$LANG['planning'][15]="Din planlægning"; 
$LANG['planning'][16]="Information"; 
$LANG['planning'][17]="Todo"; 
$LANG['planning'][18]="Færdig"; 

$LANG['plugins'][0]="Pluginliste"; 
$LANG['plugins'][2]="Installeret / ikke konfigureret"; 
$LANG['plugins'][3]="Installeret / ikke aktiveret"; 
$LANG['plugins'][4]="Fejl / skal fjernes"; 
$LANG['plugins'][5]="Ikke-eksisterende funktion(er)"; 
$LANG['plugins'][6]="Skal opdateres"; 
$LANG['plugins'][7]="Ingen plugins installeret"; 
$LANG['plugins'][8]="Se oversigten over plugins"; 
$LANG['plugins'][9]="Forfattere"; 
$LANG['plugins'][10]="Incompatible plugin with this version of GLPI"; 

$LANG['printers'][14]="Seriel"; 
$LANG['printers'][15]="Parallel"; 
$LANG['printers'][18]="Port"; 
$LANG['printers'][27]="USB"; 
$LANG['printers'][28]="Ethernet"; 
$LANG['printers'][29]="Wifi"; 
$LANG['printers'][30]="Side tæller"; 
$LANG['printers'][31]="Udskrevne sider"; 

$LANG['profiles'][0]="Global rettighed"; 
$LANG['profiles'][1]="Entity Right"; 
$LANG['profiles'][2]="Profils grænseflade"; 
$LANG['profiles'][4]="Tilføj en opfølgning til sager i tilknyttede grupper"; 
$LANG['profiles'][5]="Opret en sag"; 
$LANG['profiles'][6]="Tilføj opfølgning til sager (forespørger)"; 
$LANG['profiles'][7]="Vis alle sager"; 
$LANG['profiles'][8]="Vis alle opfølgninger og opgaver (offentlige og private)"; 
$LANG['profiles'][9]="Vis offentlige opfølgninger og opgaver"; 
$LANG['profiles'][10]="Læs"; 
$LANG['profiles'][11]="Skriv"; 
$LANG['profiles'][12]="Ingen adgang"; 
$LANG['profiles'][13]="Standard profil"; 
$LANG['profiles'][14]="Slet en sag"; 
$LANG['profiles'][15]="Tilføj opfølgning til alle sager"; 
$LANG['profiles'][16]="Overtag en sag"; 
$LANG['profiles'][17]="Stjæl en sag"; 
$LANG['profiles'][18]="Opdater en sag"; 
$LANG['profiles'][19]="Tilknyt en sag"; 
$LANG['profiles'][20]="Vis personlig planlægning"; 
$LANG['profiles'][21]="Vis alt planlægning"; 
$LANG['profiles'][22]="Profil"; 
$LANG['profiles'][23]="Administration af reservationer"; 
$LANG['profiles'][24]="Opdater kode"; 
$LANG['profiles'][26]="Vis sager oprettet af mine grupper"; 
$LANG['profiles'][27]="Se min gruppes hardware"; 
$LANG['profiles'][28]="Rekursiv"; 
$LANG['profiles'][29]="Dynamisk"; 
$LANG['profiles'][30]="Vis OCSNG information"; 
$LANG['profiles'][31]="Synkroniser OCSNG manuelt"; 
$LANG['profiles'][32]="Se tilknyttede sager (personligt og gruppe associeret)"; 
$LANG['profiles'][33]="Ingen bruger fundet"; 
$LANG['profiles'][34]="Overskrift"; 
$LANG['profiles'][35]="Opdatér alle opfølgninger"; 
$LANG['profiles'][36]="Se kalender for personer i mine grupper"; 
$LANG['profiles'][37]="Standard entitet"; 
$LANG['profiles'][38]="Synlighed"; 
$LANG['profiles'][39]="Tilknytning"; 
$LANG['profiles'][40]="Opdater"; 
$LANG['profiles'][41]="Oprettelse"; 
$LANG['profiles'][42]="Association"; 
$LANG['profiles'][43]="Metode til bruger-godkendelse og synkronisering"; 
$LANG['profiles'][44]="Skift prioriteten"; 
$LANG['profiles'][45]="Tilføj en opgave til alle sager"; 
$LANG['profiles'][46]="Redigér alle opgaver"; 
$LANG['profiles'][47]="Tilføjer brugere fra en ekstern kilde"; 
$LANG['profiles'][48]="Opret en validerings-forespørgsel"; 
$LANG['profiles'][49]="Validér en sag"; 

$LANG['registry'][1]="Hive"; 
$LANG['registry'][2]="Sti"; 
$LANG['registry'][3]="Nøgle/værdi"; 
$LANG['registry'][4]="Registreringsnøgle(r) fundet"; 
$LANG['registry'][5]="Ingen nøgle fundet i registreringsdatabasen"; 
$LANG['registry'][6]="OCSNG navn"; 

$LANG['reminder'][0]="Personlige noter"; 
$LANG['reminder'][1]="Offentlige noter"; 
$LANG['reminder'][6]="Ny note"; 
$LANG['reminder'][9]="Tekst"; 
$LANG['reminder'][12]="Tilføj til kalender"; 
$LANG['reminder'][15]="Uden overskrift"; 
$LANG['reminder'][16]="Globale noter"; 

$LANG['reports'][0]="Vælg hvilken raport du ønsker at lave"; 
$LANG['reports'][4]="Liste over hardware på kontrakt"; 
$LANG['reports'][11]="Hardware på kontrakt"; 
$LANG['reports'][12]="Hardware type"; 
$LANG['reports'][13]="Datoer"; 
$LANG['reports'][15]="Vis raport"; 
$LANG['reports'][19]="Alternativt brugernavn"; 
$LANG['reports'][26]="Standard raport"; 
$LANG['reports'][27]="pr. kontrakt"; 
$LANG['reports'][28]="pr. år"; 
$LANG['reports'][33]="Netværks raport"; 
$LANG['reports'][36]="Forbundede enheder"; 
$LANG['reports'][37]="Netværksudtag"; 
$LANG['reports'][38]="IP"; 
$LANG['reports'][39]="pr. lokation"; 
$LANG['reports'][41]="Pr. hardware"; 
$LANG['reports'][42]="Pr. netværksudtag"; 
$LANG['reports'][46]="hardwareporte"; 
$LANG['reports'][47]="enheds porte"; 
$LANG['reports'][49]="Netværksrapport pr. hardware"; 
$LANG['reports'][51]="Netværksrapport pr. udtag"; 
$LANG['reports'][52]="switch"; 
$LANG['reports'][54]="Netværk raport pr. lokation"; 
$LANG['reports'][57]="Materiale liste"; 
$LANG['reports'][58]="Udstyrsrapport pr. år"; 
$LANG['reports'][60]="Åbnings dato"; 
$LANG['reports'][61]="Lukke dato"; 
$LANG['reports'][62]="Hardware finans information"; 
$LANG['reports'][63]="Andre finans informationer (licenser, patroner, forbrugs stoffer)"; 
$LANG['reports'][64]="Løsningsdato"; 

$LANG['reservation'][1]="Emner der kan reseveres"; 
$LANG['reservation'][2]="Enhed er midlertidigt utilgængeligt"; 
$LANG['reservation'][3]="Gør utilgængelig"; 
$LANG['reservation'][5]="Gør tilgængelig"; 
$LANG['reservation'][6]="Forbyd reservationer"; 
$LANG['reservation'][7]="Godkend reservationer"; 
$LANG['reservation'][8]="Resever"; 
$LANG['reservation'][9]="Resever"; 
$LANG['reservation'][16]="Til"; 
$LANG['reservation'][17]="Fra"; 
$LANG['reservation'][18]="Det ønskede emne er allerede reseveret i dette tidsrum"; 
$LANG['reservation'][20]="Tilbage til planlægning"; 
$LANG['reservation'][21]="Vis planlægning"; 
$LANG['reservation'][22]="Ændrer komponentet"; 
$LANG['reservation'][25]="Al reserverbart hardware"; 
$LANG['reservation'][27]="Gentagelse"; 
$LANG['reservation'][28]="pr. uge"; 
$LANG['reservation'][29]="pr. dag"; 
$LANG['reservation'][30]="Antal"; 
$LANG['reservation'][31]="pr."; 
$LANG['reservation'][35]="Aktuelle og kommende reservationer"; 
$LANG['reservation'][36]="Tidligere reservationer"; 
$LANG['reservation'][37]="Ingen reservationer"; 
$LANG['reservation'][38]="Er du sikker på du vil slette dette emne fra de lånte ting ?"; 
$LANG['reservation'][39]="Dette vil fjerne alle påbegyndte reservationer"; 
$LANG['reservation'][40]="Materialereservationer der udløber i dag"; 

$LANG['rulesengine'][0]="er"; 
$LANG['rulesengine'][1]="er ikke"; 
$LANG['rulesengine'][2]="indeholder"; 
$LANG['rulesengine'][3]="indeholder ikke"; 
$LANG['rulesengine'][4]="startende med"; 
$LANG['rulesengine'][5]="færdiggjort af"; 
$LANG['rulesengine'][6]="Kriterie"; 
$LANG['rulesengine'][7]="Handlinger"; 
$LANG['rulesengine'][8]="Regel-håndtering"; 
$LANG['rulesengine'][9]="Logisk operator"; 
$LANG['rulesengine'][10]="Position"; 
$LANG['rulesengine'][11]="Handlingstype"; 
$LANG['rulesengine'][12]="Felter"; 
$LANG['rulesengine'][13]="Værdi"; 
$LANG['rulesengine'][14]="Betingelse"; 
$LANG['rulesengine'][15]="Årsag"; 
$LANG['rulesengine'][16]="Kriterie"; 
$LANG['rulesengine'][17]="Regler"; 
$LANG['rulesengine'][18]="Rules for assigning a computer to an entity"; 
$LANG['rulesengine'][19]="Entity and rights assignment rules"; 
$LANG['rulesengine'][20]="Regler anvendt"; 
$LANG['rulesengine'][21]="Rules applicable in the sub-entities"; 
$LANG['rulesengine'][22]="Tilknyt"; 
$LANG['rulesengine'][23]="Lokale regler"; 
$LANG['rulesengine'][24]="Regeltype"; 
$LANG['rulesengine'][25]="Navn på computer"; 
$LANG['rulesengine'][26]="regular expression checks"; 
$LANG['rulesengine'][27]="regular expression does not match"; 
$LANG['rulesengine'][28]="Forretningsregler for sager"; 
$LANG['rulesengine'][29]="List rules"; 
$LANG['rulesengine'][30]="Handling"; 
$LANG['rulesengine'][33]="Dropdown dictionary"; 
$LANG['rulesengine'][35]="Software bibliotek"; 
$LANG['rulesengine'][36]="Producent bibliotek"; 
$LANG['rulesengine'][37]="Rules for assigning a category to software"; 
$LANG['rulesengine'][38]="Genberegn"; 
$LANG['rulesengine'][40]="kategorien"; 
$LANG['rulesengine'][41]="Validering"; 
$LANG['rulesengine'][42]="AND"; 
$LANG['rulesengine'][43]="OR"; 
$LANG['rulesengine'][45]="Assign the value from regular expression"; 
$LANG['rulesengine'][46]="Tilknyt: udstyr ip adresse"; 
$LANG['rulesengine'][47]="Tilknyt: udstyr efter navn + domæne"; 
$LANG['rulesengine'][48]="Tilknyt udstyr"; 
$LANG['rulesengine'][49]="Tilknyt: udstyr efter MAC-adresse"; 
$LANG['rulesengine'][50]="Computermodel bibliotek"; 
$LANG['rulesengine'][51]="Skærmmodel bibliotek"; 
$LANG['rulesengine'][52]="Telefonmodel bibliotek"; 
$LANG['rulesengine'][53]="Peripheral model dictionary"; 
$LANG['rulesengine'][54]="Printermodel bibliotek"; 
$LANG['rulesengine'][55]="Netværksmodel bibliotek"; 
$LANG['rulesengine'][56]="Modeller"; 
$LANG['rulesengine'][60]="Computertype bibliotek"; 
$LANG['rulesengine'][61]="Skærmtype bibliotek"; 
$LANG['rulesengine'][62]="Telefontype bibliotek"; 
$LANG['rulesengine'][63]="Peripheral type dictionary"; 
$LANG['rulesengine'][64]="Printertype bibliotek"; 
$LANG['rulesengine'][65]="Netværks-enhedstype bibliotek"; 
$LANG['rulesengine'][66]="Typer"; 
$LANG['rulesengine'][67]="Operativsystem bibliotek"; 
$LANG['rulesengine'][68]="Servicepack bibliotek"; 
$LANG['rulesengine'][69]="OS version bibliotek"; 
$LANG['rulesengine'][70]="Rules for assigning a ticket created through a mail receiver"; 
$LANG['rulesengine'][76]="Omdøb baseret på bibliotek"; 
$LANG['rulesengine'][77]="Ordbøger"; 
$LANG['rulesengine'][78]="Version"; 
$LANG['rulesengine'][79]="Tilføj resultatet fra en regex"; 
$LANG['rulesengine'][80]="Globalt bibliotek"; 
$LANG['rulesengine'][81]="Regel-resultat"; 
$LANG['rulesengine'][82]="Result details"; 
$LANG['rulesengine'][83]="It is possible to affect the result of a regular expression using the string #0"; 
$LANG['rulesengine'][84]="Test rules engine"; 
$LANG['rulesengine'][85]="Result of the regular expression"; 
$LANG['rulesengine'][86]="Softwarecategory affected when software deleted by dictionary"; 
$LANG['rulesengine'][87]="Software slettet af GLPI bibliotek"; 
$LANG['rulesengine'][90]="Arbejde i gang..."; 
$LANG['rulesengine'][91]="Arbejde afsluttet."; 
$LANG['rulesengine'][92]="Warning before running rename based on the dictionary"; 
$LANG['rulesengine'][93]="Warning! This operation can put software in the trash.<br>Sure to notify your users."; 
$LANG['rulesengine'][94]="FUSION"; 
$LANG['rulesengine'][95]="Manufacturer choice"; 
$LANG['rulesengine'][96]="Omdøb baseret på producent bibliotek<br> ( ----- = Alle)"; 
$LANG['rulesengine'][97]="Ingen emner der skal testes"; 
$LANG['rulesengine'][100]="Cache oplysninger"; 
$LANG['rulesengine'][102]="Regelnavn"; 
$LANG['rulesengine'][103]="Objects in cache"; 
$LANG['rulesengine'][104]="Original værdi"; 
$LANG['rulesengine'][105]="Ændret værdi"; 
$LANG['rulesengine'][106]="Uændret"; 
$LANG['rulesengine'][107]="Inaktiv"; 
$LANG['rulesengine'][108]="original"; 
$LANG['rulesengine'][110]="Rights assignment"; 
$LANG['rulesengine'][111]="Entities assignment"; 
$LANG['rulesengine'][112]="Rights and entities assignment"; 
$LANG['rulesengine'][120]="The engine stops on the first checked rule."; 
$LANG['rulesengine'][121]="The engine treats all the rules."; 
$LANG['rulesengine'][122]="The engine passes the result of a rule to the following ones."; 
$LANG['rulesengine'][130]="Entitet fra LDAP"; 
$LANG['rulesengine'][131]="Entity from TAG"; 
$LANG['rulesengine'][132]="To be unaware of import"; 
$LANG['rulesengine'][133]="Entitet fra domæne"; 
$LANG['rulesengine'][134]="Afvis mail (uden email svar)"; 
$LANG['rulesengine'][135]="Afvis email (med email svar)"; 
$LANG['rulesengine'][138]="LDAP kriterier"; 
$LANG['rulesengine'][140]="Tilføjer et kriterie"; 
$LANG['rulesengine'][142]="List of not imported emails"; 
$LANG['rulesengine'][144]="Entity based on user's profile"; 
$LANG['rulesengine'][145]="Bruger med en enkelt profil"; 
$LANG['rulesengine'][146]="Bruger med profilen"; 
$LANG['rulesengine'][147]="User featuring a single profile"; 
$LANG['rulesengine'][148]="E-maildomæne er kendt"; 
$LANG['rulesengine'][150]="The rules linked with the entity have been disabled."; 

$LANG['search'][0]="Søg"; 
$LANG['search'][1]="efter alle"; 
$LANG['search'][2]="indeholder"; 
$LANG['search'][4]="sorteret efter"; 
$LANG['search'][8]="Startdato"; 
$LANG['search'][9]="Slutdato"; 
$LANG['search'][10]="i"; 
$LANG['search'][11]="Viste emner"; 
$LANG['search'][12]="Indikér en slutdato"; 
$LANG['search'][15]="Intet emne fundet"; 
$LANG['search'][16]="Mindst"; 
$LANG['search'][17]="Tilføj et søgekriterie"; 
$LANG['search'][18]="Slet et søgekriterie"; 
$LANG['search'][19]="Tilføj et globalt søgekriterie."; 
$LANG['search'][20]="Tilføj et globalt søgekriterie"; 

$LANG['setup'][0]="Dropdowns"; 
$LANG['setup'][2]="Tilføj bruger..."; 
$LANG['setup'][3]="LDAP bibliotek link"; 
$LANG['setup'][4]="Computer typer"; 
$LANG['setup'][5]="Operativsystemer"; 
$LANG['setup'][6]="Personalization"; 
$LANG['setup'][9]="Netværks interface"; 
$LANG['setup'][10]="Display order of surnames firstnames"; 
$LANG['setup'][14]="E-mail"; 
$LANG['setup'][18]="Login"; 
$LANG['setup'][19]="Kodeord"; 
$LANG['setup'][20]="Password confirmation"; 
$LANG['setup'][21]="Error : the two passwords are not identical"; 
$LANG['setup'][35]="MHz"; 
$LANG['setup'][39]="Followed private for default"; 
$LANG['setup'][40]="Private opgaver som standard"; 
$LANG['setup'][41]="Vælg sprog"; 
$LANG['setup'][42]="Netværks typer"; 
$LANG['setup'][43]="Printer typer"; 
$LANG['setup'][44]="Skærmtyper"; 
$LANG['setup'][45]="Sags type"; 
$LANG['setup'][46]="Standardværdi"; 
$LANG['setup'][47]="Standard diagram format"; 
$LANG['setup'][48]="Standardværdier"; 
$LANG['setup'][62]="Vælg kategori der skal konfigureres"; 
$LANG['setup'][63]="Forsigtig: Du er ved at slette en overskrift brugt til 1 eller flere ting."; 
$LANG['setup'][64]="Hvis du godkender sletningen vil emner der indeholder denne overskrift blive blanket"; 
$LANG['setup'][65]="You can also replace all the events of this heading by another:"; 
$LANG['setup'][67]="Eksterne godkendelser"; 
$LANG['setup'][69]="Enheds typer"; 
$LANG['setup'][70]="Generel opsætning"; 
$LANG['setup'][71]="Firmware"; 
$LANG['setup'][73]="Netværksudtag"; 
$LANG['setup'][74]="You can't delete that place, because it has sub-places"; 
$LANG['setup'][75]="Som et barn af"; 
$LANG['setup'][79]="Sags-kategorier"; 
$LANG['setup'][80]="Tredie parts type"; 
$LANG['setup'][81]="Dokument overskrift"; 
$LANG['setup'][82]="Kontakt type"; 
$LANG['setup'][83]="Emne status"; 
$LANG['setup'][84]="Patron type"; 
$LANG['setup'][85]="Kontrakt tye"; 
$LANG['setup'][86]="Hukommelsestype"; 
$LANG['setup'][87]="Vidensdatabase kategorier"; 
$LANG['setup'][88]="Netværk"; 
$LANG['setup'][89]="Domæne"; 
$LANG['setup'][90]="VLAN"; 
$LANG['setup'][91]="Computer modeller"; 
$LANG['setup'][92]="Forbrugs type"; 
$LANG['setup'][93]="Hard Disk Interface"; 
$LANG['setup'][94]="Skærm-modeller"; 
$LANG['setup'][95]="Netværks modeller"; 
$LANG['setup'][96]="Printer modeller"; 
$LANG['setup'][97]="ydre enheds typer"; 
$LANG['setup'][98]="Opgaver kategori"; 
$LANG['setup'][99]="Bygningsnummer"; 
$LANG['setup'][100]="Lokalenr."; 
$LANG['setup'][101]="Maksimum antal automatiske hændelser (kørt af CLI)"; 
$LANG['setup'][102]="Logniveau"; 
$LANG['setup'][103]="1- Kritisk (kun login fejl)"; 
$LANG['setup'][104]="2- Alvorlig (ikke brugt)"; 
$LANG['setup'][105]="3- Vigtig (login lykkedes)"; 
$LANG['setup'][106]="4- Beskeder (tilføj, slet, søgning)"; 
$LANG['setup'][107]="5- Komplet (alle)"; 
$LANG['setup'][109]="Hvor længe skal systemlog gemmes i databasen ( i dage, 0 for uendeligt)"; 
$LANG['setup'][110]="Vis nye sager på startsiden"; 
$LANG['setup'][111]="Maksimum antal søgeresultater der vises på en side"; 
$LANG['setup'][112]="Maksimum antal tegn for hvert emne i dropdowns"; 
$LANG['setup'][113]="Standard sprog"; 
$LANG['setup'][114]="Farve på prioteter"; 
$LANG['setup'][115]="Standard grænse for patroner og forbrugs antal"; 
$LANG['setup'][116]="Tildel automatisk sagerne til den ansvarlige tekniker"; 
$LANG['setup'][117]="Godkend anonym visning af FAQ"; 
$LANG['setup'][118]="Tekst på login siden"; 
$LANG['setup'][119]="Vis"; 
$LANG['setup'][120]="Brug dynamisk visning for dropdowns og tekstfelter"; 
$LANG['setup'][121]="Tegn der gennemtvinger den fulde visning af dropdowns (wildcard)"; 
$LANG['setup'][122]="Maksimum antal emner der vises i dropdowns når der ikke bruges wildcard"; 
$LANG['setup'][123]="Brug ikke dynamisk visning, hvis antallet af emner er mindre end"; 
$LANG['setup'][124]="Tilføj automatisk brugere af en ekstern godkendelses kilde"; 
$LANG['setup'][125]="... Fra en ekstern kilde"; 
$LANG['setup'][126]="Automatisk tilføj en bruger af en ekstern kilde"; 
$LANG['setup'][127]="Autofuldførelse af tekstfelter"; 
$LANG['setup'][128]="Data format"; 
$LANG['setup'][129]="Vis GLPI ID"; 
$LANG['setup'][130]="Antal dage disse hændelseslogfiler gemmes"; 
$LANG['setup'][132]="Display the complete name in the tree dropdowns"; 
$LANG['setup'][133]="Aktivér OCSNG tilstand"; 
$LANG['setup'][134]="OCSNG tilstand"; 
$LANG['setup'][135]="Normal"; 
$LANG['setup'][136]="Oversættelse"; 
$LANG['setup'][137]="Debug"; 
$LANG['setup'][138]="Use GLPI in Mode"; 
$LANG['setup'][139]="Almindelig"; 
$LANG['setup'][140]="Typer"; 
$LANG['setup'][145]="Os"; 
$LANG['setup'][147]="Dynamisk visning"; 
$LANG['setup'][148]="Step for the hours"; 
$LANG['setup'][149]="Antal decimaler i beløb"; 
$LANG['setup'][150]="Number Format"; 
$LANG['setup'][154]="Basedn"; 
$LANG['setup'][155]="rootdn (for non anonymous binds)"; 
$LANG['setup'][156]="Pass (for non-anonymous binds)"; 
$LANG['setup'][157]="LDAP udvidelsen i din PHP fortolker er ikke installeret"; 
$LANG['setup'][158]="Umuligt at bruge LDAP som ekstern kilde til forbindelse"; 
$LANG['setup'][159]="Forbindelses filter"; 
$LANG['setup'][162]="IMAP/POP Konfiguration"; 
$LANG['setup'][164]="IMAP/POP værtsnavn <br>(brugeres e-mail vil være login@thishost)"; 
$LANG['setup'][165]="Your parser PHP was compiled without the IMAP functions"; 
$LANG['setup'][166]="Umuligt at bruge IMAP/POP som ekstern kilde til forbindelser"; 
$LANG['setup'][167]="LDAP bibliotek / GLPI links"; 
$LANG['setup'][168]="Forbindelses muligheder"; 
$LANG['setup'][169]="Postbakke (valgfri, ofte INBOX)"; 
$LANG['setup'][170]="Tilslutnings-streng"; 
$LANG['setup'][171]="Port (frivillig)"; 
$LANG['setup'][172]="Port (standard=389)"; 
$LANG['setup'][174]="CAS Host"; 
$LANG['setup'][175]="Port"; 
$LANG['setup'][176]="Root directory (optional)"; 
$LANG['setup'][177]="CAS konfiguration"; 
$LANG['setup'][178]="CURL eller DOMXML udvidelserne til din PHP fortolker er ikke installeret"; 
$LANG['setup'][179]="Impossible to use CAS as external source of connection"; 
$LANG['setup'][180]="Brug TLS"; 
$LANG['setup'][181]="ldap_start_tls eksisterer ikke"; 
$LANG['setup'][182]="Logout fallback URL"; 
$LANG['setup'][185]="Logs i filer (SQL, e-mail, automatisk hændelse...)"; 
$LANG['setup'][186]="Tidszone"; 
$LANG['setup'][190]="x509 certifikat"; 
$LANG['setup'][191]="email-attribut for x509"; 
$LANG['setup'][192]="Aktiveret"; 
$LANG['setup'][193]="Field holding the login in the _SERVER array"; 
$LANG['setup'][194]="Yderligere informationshentning fra LDAP bibliotek"; 
$LANG['setup'][195]="Behold status"; 
$LANG['setup'][196]="Ryd status"; 
$LANG['setup'][197]="Kopier computerstatus"; 
$LANG['setup'][198]="Sæt status"; 
$LANG['setup'][199]="Remove the domain of login in form login@domain"; 
$LANG['setup'][200]="Uendelig"; 
$LANG['setup'][201]="Alarm og email-opfølgnings konfiguration"; 
$LANG['setup'][202]="Aktivér opfølgning via e-mail"; 
$LANG['setup'][203]="Administrator e-mail"; 
$LANG['setup'][204]="E-mail signatur"; 
$LANG['setup'][205]="E-mail sendt til administrator"; 
$LANG['setup'][206]="Kunne ikke sende en e-mail til administrator"; 
$LANG['setup'][207]="Administrator svar-til e-mail (hvis påkrævet)"; 
$LANG['setup'][217]="The PHP mail function is unknown or isn't activated on your system"; 
$LANG['setup'][218]="Brugen af SMTP er påkrævet"; 
$LANG['setup'][219]="Tillad anonym oprettelse af sager (helpdesk.receiver)"; 
$LANG['setup'][221]="Begyndelse af regnskabsår"; 
$LANG['setup'][223]="Begrænsning af kalender for planlægning"; 
$LANG['setup'][227]="Applikationens URL"; 
$LANG['setup'][228]="Loginfelt"; 
$LANG['setup'][229]="Send en test e-mail til administratoren"; 
$LANG['setup'][231]="Brug en SMTP server til at sende e-mails"; 
$LANG['setup'][232]="SMTP vært"; 
$LANG['setup'][234]="SMTP login (valgfri)"; 
$LANG['setup'][235]="SMTP kodeord (valgfri)"; 
$LANG['setup'][236]="Tidligere sags-ansvarlige tekniker"; 
$LANG['setup'][237]="Administrator"; 
$LANG['setup'][239]="Sags-ansvarlig tekniker"; 
$LANG['setup'][240]="Påmindelses indstillinger"; 
$LANG['setup'][241]="Ingen personlige kriterier. Opret personlige parametre?"; 
$LANG['setup'][242]="Alarm indstillinger"; 
$LANG['setup'][243]="Alarm på forbrugs varer"; 
$LANG['setup'][244]="Alarm på patroner"; 
$LANG['setup'][245]="Påmindelsesfrekvens"; 
$LANG['setup'][246]="Alarm på kontrakter"; 
$LANG['setup'][247]="Alarm på finans informationer"; 
$LANG['setup'][248]="Ansvarlig gruppe for sagen"; 
$LANG['setup'][249]="Forespørgergruppe"; 
$LANG['setup'][250]="Standard søge liste"; 
$LANG['setup'][252]="Vælg hvilken standard emner der skal vises"; 
$LANG['setup'][253]="Søge filter til søgning i grupper"; 
$LANG['setup'][254]="Søge type"; 
$LANG['setup'][255]="Gruppe attrubuter indeholdende dens brugere"; 
$LANG['setup'][256]="I brugere"; 
$LANG['setup'][257]="I grupper"; 
$LANG['setup'][258]="Brugere og grupper"; 
$LANG['setup'][259]="Tilhørende til grupper"; 
$LANG['setup'][260]="User attribute containing its groups"; 
$LANG['setup'][261]="Gruppe DN"; 
$LANG['setup'][262]="Brug DN i søgningen"; 
$LANG['setup'][263]="Search filter for users"; 
$LANG['setup'][264]="Besked ved udløbede licenser"; 
$LANG['setup'][271]="Begræns skærm håndtering"; 
$LANG['setup'][272]="Begræns enheds håndtering"; 
$LANG['setup'][273]="Begræns telefon håndtering"; 
$LANG['setup'][274]="for manuel tilføjelse"; 
$LANG['setup'][275]="Begræns printer håndtering"; 
$LANG['setup'][280]="Automatisk opdatering af de emner der er relateret til computerne"; 
$LANG['setup'][281]="Ved tilslutning eller opdatering"; 
$LANG['setup'][282]="Ved frakobling"; 
$LANG['setup'][283]="Kopier"; 
$LANG['setup'][284]="Ryd"; 
$LANG['setup'][285]="Kopier ikke"; 
$LANG['setup'][286]="Slet ikke"; 
$LANG['setup'][300]="Check om der er en ny version tilgængelig"; 
$LANG['setup'][301]="En ny version er tilgængelig"; 
$LANG['setup'][302]="Du kan finde det på GLPI-PROJECT.org webstedet"; 
$LANG['setup'][303]="Du har den nyeste tilgængelige version"; 
$LANG['setup'][304]="Forbindelse mislykket. Hvis du bruger en proxy så omkonfigurer den venligst."; 
$LANG['setup'][305]="Hver dag"; 
$LANG['setup'][306]="Check for opdatering"; 
$LANG['setup'][307]="Aldrig"; 
$LANG['setup'][308]="Hver uge"; 
$LANG['setup'][309]="Hver måned"; 
$LANG['setup'][310]="Impossible to connect to site."; 
$LANG['setup'][311]="Kunne ikke forbinde til proxy serveren"; 
$LANG['setup'][312]="No data available on the web site"; 
$LANG['setup'][313]="Vær forsigtig : der er ikke nogen standardværdi"; 
$LANG['setup'][350]="Link med emnerne til oprettelsen af sager"; 
$LANG['setup'][351]="Alle ting"; 
$LANG['setup'][352]="Linkbare emner til en sag"; 
$LANG['setup'][360]="Automatiske felter (markeret med *)"; 
$LANG['setup'][400]="Proxy konfiguration"; 
$LANG['setup'][407]="Simplified interface help link"; 
$LANG['setup'][408]="Standard interface help link"; 
$LANG['setup'][409]="Default heading when adding a document to a ticket"; 
$LANG['setup'][503]="Telefon modeller"; 
$LANG['setup'][504]="Telefon typer"; 
$LANG['setup'][505]="Power supply type of phones"; 
$LANG['setup'][601]="LDAP værdi"; 
$LANG['setup'][602]="Forbindelse til OCSNG databasen"; 
$LANG['setup'][603]="Tilføj en bruger"; 
$LANG['setup'][604]="Tildel til en gruppe"; 
$LANG['setup'][606]="Unable to add. The user already exists."; 
$LANG['setup'][607]="Tilknyt til en profil"; 
$LANG['setup'][608]="Software associable to a ticket by default"; 
$LANG['setup'][609]="Kunne ikke tilføje. OCSNG serveren eksistere allerede."; 
$LANG['setup'][610]="Compulsory title of the ticket"; 
$LANG['setup'][611]="Compulsory ticket content"; 
$LANG['setup'][612]="Compulsory ticket category"; 
$LANG['setup'][613]="Add a user who have no accreditation from a LDAP directory"; 
$LANG['setup'][614]="Unable to update login. A user already exists."; 
$LANG['setup'][615]="Sagers livscyklus"; 
$LANG['setup'][616]="Fra \ Til"; 
$LANG['setup'][620]="Link"; 
$LANG['setup'][621]="Search filter for entities"; 
$LANG['setup'][622]="Attribute representing entity"; 
$LANG['setup'][623]="Importer entiteter fra LDAP bibliotek"; 
$LANG['setup'][650]="PHP"; 
$LANG['setup'][651]="SMTP"; 
$LANG['setup'][652]="SMTP+SSL"; 
$LANG['setup'][653]="SMTP+TLS"; 
$LANG['setup'][660]="Mailserver"; 
$LANG['setup'][661]="Kunne ikke konfigurere påmindelserne : aktiver venligst e-mail overvågning"; 
$LANG['setup'][703]="Generel"; 
$LANG['setup'][704]="Påmindelser"; 
$LANG['setup'][707]="Besked ved reservation"; 
$LANG['setup'][708]="Påmindelse ved sager der ikke er løst siden"; 
$LANG['setup'][720]="Systemoplysninger"; 
$LANG['setup'][721]="Information om system-installation og konfiguration"; 
$LANG['setup'][722]="Til at klippe/kliste i din support forespørgsel"; 
$LANG['setup'][731]="Value of the global configuration"; 
$LANG['setup'][732]="Domain of electronic mail service"; 
$LANG['setup'][800]="MySQL replika"; 
$LANG['setup'][801]="Aktivér MySQL replika"; 
$LANG['setup'][802]="Database"; 
$LANG['setup'][803]="Difference between master and slave"; 
$LANG['setup'][806]="Max delay between master and slave (minutes)"; 
$LANG['setup'][807]="The slave base is desynchronized. The difference is of:"; 
$LANG['setup'][808]="Slave database out of sync!"; 
$LANG['setup'][809]="MySQL replika: kun læs"; 
$LANG['setup'][810]="Afsynkroniserer MySQL replikering"; 

$LANG['software'][1]="Købt version"; 
$LANG['software'][2]="Brug version"; 
$LANG['software'][3]="Not installed affected licenses"; 
$LANG['software'][4]="Ubegrænset"; 
$LANG['software'][5]="Versioner"; 
$LANG['software'][6]="Udgiver"; 
$LANG['software'][7]="Tilføj en version"; 
$LANG['software'][8]="Tilføj en licens"; 
$LANG['software'][11]="Licenser"; 
$LANG['software'][17]="Installeret Software"; 
$LANG['software'][19]="Installationer"; 
$LANG['software'][20]="Tilbageværende"; 
$LANG['software'][28]="OEM"; 
$LANG['software'][29]="Opdater"; 
$LANG['software'][30]="Licenstyper"; 
$LANG['software'][32]="Udløber"; 
$LANG['software'][44]="Installeret software"; 
$LANG['software'][45]="Uninstall software"; 
$LANG['software'][46]="Tilknyttet til en sag"; 
$LANG['software'][47]="Sammenlægger"; 
$LANG['software'][48]="Sammenlæg"; 
$LANG['software'][49]="Software slettet efter sammenlægning"; 
$LANG['software'][50]="Tilknyttet til computeren"; 
$LANG['software'][51]="Tallet skal være 1 for at kunne påvirke"; 

$LANG['softwarecategories'][2]="Ikke-kategoriseret software"; 
$LANG['softwarecategories'][3]="Unfold the software without category"; 
$LANG['softwarecategories'][4]="Unfold the software belonging to a category"; 
$LANG['softwarecategories'][5]="Softwarekategori"; 

$LANG['state'][0]="Status"; 
$LANG['state'][6]="Type"; 
$LANG['state'][7]="Intet fundet"; 
$LANG['state'][11]="Resume"; 

$LANG['stats'][0]="Vælg statistik der skal vises"; 
$LANG['stats'][1]="Global"; 
$LANG['stats'][2]="Ingen emner at vise"; 
$LANG['stats'][3]="Pr. enhed"; 
$LANG['stats'][5]="Antal åbne sager"; 
$LANG['stats'][6]="Gennemsnitlig løsnings forsinkelse"; 
$LANG['stats'][7]="Vis grafik"; 
$LANG['stats'][11]="Antal løste sager"; 
$LANG['stats'][13]="Antal sager"; 
$LANG['stats'][15]="Gennemsnitlig løsnings forsinkelse"; 
$LANG['stats'][16]="Tekniker navn"; 
$LANG['stats'][20]="Brugernavn"; 
$LANG['stats'][23]="Ingen statistiker tilgængelig"; 
$LANG['stats'][25]="Gennemsnitlig (rigtig) varighed af sag"; 
$LANG['stats'][27]="Total (rigtig) varighed af sag"; 
$LANG['stats'][30]="Gennemsnitlig forsinkelse før bevarelse af en sag"; 
$LANG['stats'][31]="Dag/Dage"; 
$LANG['stats'][33]="Minut/Minuter"; 
$LANG['stats'][34]="Sekunder"; 
$LANG['stats'][35]="Sag(er)"; 
$LANG['stats'][44]="Leverandør-navn"; 
$LANG['stats'][45]="For hardware"; 
$LANG['stats'][47]="Pr. sag"; 
$LANG['stats'][48]="(tildelt)"; 
$LANG['stats'][49]="(opfølgning)"; 

$LANG['title'][5]="Vidensdatabase"; 
$LANG['title'][6]="Netværk"; 
$LANG['title'][9]="Enheds status"; 
$LANG['title'][10]="Sags-opfølgning"; 
$LANG['title'][13]="Bruger information"; 
$LANG['title'][14]="Eksterne godkendelses enheder"; 
$LANG['title'][24]="Assistance"; 
$LANG['title'][26]="Hoved"; 
$LANG['title'][27]="Forbindelser"; 
$LANG['title'][28]="Sager"; 
$LANG['title'][30]="Komponenter"; 
$LANG['title'][33]="Eksterne links"; 
$LANG['title'][34]="Links"; 
$LANG['title'][37]="Noter"; 
$LANG['title'][38]="Historik"; 
$LANG['title'][40]="Offentlige og personlige notater"; 
$LANG['title'][42]="Massive modifikationer"; 
$LANG['title'][43]="Registreringsdatabase"; 

$LANG['tracking'][1]="Mine enheder"; 
$LANG['tracking'][2]="Eller komplet søgning"; 
$LANG['tracking'][3]="Ugyldige datoer. Opdatering afbrudt."; 
$LANG['tracking'][4]="Der er ikke angivet vigtighed i din sag, ret det venligst."; 
$LANG['tracking'][8]="Ingen beskrivelse af din sag, prøv venligst igen."; 
$LANG['tracking'][9]="Standard for sager"; 
$LANG['tracking'][10]="Standard for mail-modtagere"; 
$LANG['tracking'][24]="Dokument sag"; 
$LANG['tracking'][29]="Antal"; 
$LANG['tracking'][30]="Ny"; 
$LANG['tracking'][31]="Behandler (tildelt)"; 
$LANG['tracking'][32]="Behandler (planlagt)"; 
$LANG['tracking'][34]="Direkte"; 
$LANG['tracking'][35]="Skrevet"; 
$LANG['tracking'][37]="Behold sager når hardware bliver slettet fra lageret"; 
$LANG['tracking'][38]="En email blev sendt til"; 
$LANG['tracking'][39]="Synlig i den simple brugerflade"; 

$LANG['transfer'][1]="Overfør"; 
$LANG['transfer'][3]="Hvis ikke længere i brug"; 
$LANG['transfer'][4]="For at tømme listen med emner der skal overføres"; 
$LANG['transfer'][5]="Du kan fortsætte med at tilføje emner der skal overføres eller udføre overførslen nu"; 
$LANG['transfer'][6]="Think of making a backup before transferring items."; 
$LANG['transfer'][7]="Items to transfer"; 
$LANG['transfer'][8]="Overførselstilstand"; 

$LANG['update'][88]="Din version af databasen er ikke kompatibel med versionen af installerede filer. En opdatering er nødvendig."; 
$LANG['update'][89]="Du prøver at bruge GLPI med filer fra en tidligere version i forhold til databasen. Installér venligst versionen svarende til din database."; 
$LANG['update'][90]="Fejl under opdatering af databasen"; 
$LANG['update'][91]="Forsigtig !"; 
$LANG['update'][92]="Du vil updatere GLPI databasen med navnet :"; 
$LANG['update'][93]="Database forbindelse lykkedes"; 
$LANG['update'][94]="Opdatering lykkedes, din database op opdateret"; 
$LANG['update'][95]="Forbindelsen til databasen fejlede, check forbindelses parametrene inkluderet i config_db.php filen."; 
$LANG['update'][96]="Nu har alle administratorene 'super-admin' rettigheder. Denne nye bruger er også blevet tilføjet."; 
$LANG['update'][105]="Umuligt at opdatere på denne måde!!"; 
$LANG['update'][106]="Gå tilbage til GLPI"; 
$LANG['update'][107]="Du kan nu fortsætte med at opdatere indholdet af din database"; 
$LANG['update'][130]="Lokationer opdateret"; 
$LANG['update'][131]="Den nye struktur er hirakisk"; 
$LANG['update'][132]="If you used a splitting character, you can set it in order to automate the generation of the new hierarchy."; 
$LANG['update'][133]="Du kan også specificere en rod lokation som vil inkludere alle de lavede lokationer."; 
$LANG['update'][134]="Delte karakterer"; 
$LANG['update'][135]="Root mappe"; 
$LANG['update'][136]="Dette er det nye hiraki. Hvis det er ok kan du validere det."; 
$LANG['update'][137]="Nyt hiraki"; 
$LANG['update'][138]="Rigtig lokation"; 
$LANG['update'][139]="Tabel-optimering"; 
$LANG['update'][140]="Opretter index"; 
$LANG['update'][141]="Ændring af databaseskema"; 
$LANG['update'][142]="Datamigrering"; 

$LANG['users'][1]="Titel"; 
$LANG['users'][2]="Kategori (klasse)"; 

$LANG['validation'][0]="Validering"; 
$LANG['validation'][1]="Send a Approval request"; 
$LANG['validation'][2]="Status"; 
$LANG['validation'][3]="Request date"; 
$LANG['validation'][4]="Valideringsdato"; 
$LANG['validation'][5]="Request comment"; 
$LANG['validation'][6]="Godkendelses kommentar"; 
$LANG['validation'][7]="Validering(er) af sagen"; 
$LANG['validation'][9]="Venter på validering"; 
$LANG['validation'][10]="Afvist"; 
$LANG['validation'][11]="Accepteret"; 
$LANG['validation'][12]="Not subject to approval"; 
$LANG['validation'][13]="Approval request send to"; 
$LANG['validation'][15]="Sager der afventer din validering"; 
$LANG['validation'][16]="Optional when approved"; 
$LANG['validation'][18]="Validerings forespørger"; 
$LANG['validation'][19]="Validering accepteret"; 
$LANG['validation'][20]="Validering afvist"; 
$LANG['validation'][21]="Validerings-bruger"; 
$LANG['validation'][23]="The selected user has no valid emailaddress. The request has been created, without email confirmation."; 
$LANG['validation'][26]="Valideringsforespørgsel"; 
$LANG['validation'][27]="An approval request has been submitted"; 
$LANG['validation'][28]="Status of the Approval request"; 
$LANG['validation'][29]="If approval is denied, specify a reason"; 
$LANG['validation'][30]="Cancel the approval request to"; 
$LANG['validation'][31]="Opdatér godkendelses-forespørgslen til"; 
$LANG['validation'][32]="An answer to a Approval request was produced"; 
$LANG['validation'][33]="Sager der afventer godkendelse"; 
?>